@@ -1,10 +1,11 @@
-# pylint: disable=invalid-name
 """Utilities package for my other projects."""
+
 from __future__ import annotations
 
 name = "wg_utilities"
 
-__version__ = "5.3.1"
+__version__ = "5.17.4"
+
 
 __all__ = [
     "api",
@@ -13,6 +14,7 @@ __all__ = [
     "devices",
     "exceptions",
     "functions",
+    "helpers",
     "loggers",
     "testing",
 ]
