@@ -2,10 +2,9 @@
 
 from __future__ import annotations
 
-from datetime import datetime
 from textwrap import dedent
 from threading import Thread
-from time import sleep
+from time import sleep, time
 from typing import Any, cast
 
 from flask import Flask, Response, request
@@ -90,7 +89,7 @@ class TempAuthServer:
 
         @self.app.route("/get_auth_code", methods=["GET"])
         def get_auth_code() -> Response:
-            # TODO add 400 response for mismatch in state token
+            # TODO: add 400 response for mismatch in state token
             """Endpoint for getting auth code from third party callback.
 
             Returns:
@@ -118,14 +117,18 @@ class TempAuthServer:
                         <span>Click anywhere to close this window.</span>
                     </body>
                     </html>
-                """
+                """,
                     ).strip(),
                     status=200,
                 ),
             )
 
     def wait_for_request(
-        self, endpoint: str, max_wait: int = 300, *, kill_on_request: bool = False
+        self,
+        endpoint: str,
+        max_wait: int = 300,
+        *,
+        kill_on_request: bool = False,
     ) -> dict[str, Any]:
         """Wait for a request.
 
@@ -143,19 +146,18 @@ class TempAuthServer:
         Raises:
             TimeoutError: if no request is received within the timeout limit
         """
-
         if not self.is_running:
             self.start_server()
 
-        start_time = datetime.utcnow()
+        start_time = time()
         while (
-            time_elapsed := (datetime.utcnow() - start_time).seconds
+            time_elapsed := time() - start_time
         ) <= max_wait and not self._request_args.get(endpoint):
             sleep(0.5)
 
         if time_elapsed > max_wait:
             raise TimeoutError(
-                f"No request received to {endpoint} within {max_wait} seconds"
+                f"No request received to {endpoint} within {max_wait} seconds",
             )
 
         if kill_on_request:
@@ -241,7 +243,9 @@ class TempAuthServer:
         """
         if not hasattr(self, "_server_thread"):
             self._server_thread = self.ServerThread(
-                self.app, host=self.host, port=self._user_port
+                self.app,
+                host=self.host,
+                port=self._user_port,
             )
 
         return self._server_thread
