@@ -1,4 +1,5 @@
 """Generic Google Client - having one client for all APIs is way too big."""
+
 from __future__ import annotations
 
 from collections.abc import Callable, Iterable, Mapping
@@ -10,22 +11,21 @@ from typing import TYPE_CHECKING, Any, ClassVar, Generic, Literal, TypeAlias, Ty
 from requests import Response, get
 from typing_extensions import TypedDict
 
-from wg_utilities.clients.json_api_client import StrBytIntFlt
-from wg_utilities.clients.oauth_client import OAuthClient
-from wg_utilities.loggers import add_stream_handler
+from .oauth_client import OAuthClient
 
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
-add_stream_handler(LOGGER)
 
 
 if TYPE_CHECKING:  # pragma: no cover
     from wg_utilities.clients.google_calendar import GoogleCalendarEntityJson
     from wg_utilities.clients.google_photos import GooglePhotosEntityJson
+    from wg_utilities.clients.json_api_client import StrBytIntFlt
 
 
 GetJsonResponseGoogleClient = TypeVar(
-    "GetJsonResponseGoogleClient", bound=Mapping[Any, Any]
+    "GetJsonResponseGoogleClient",
+    bound=Mapping[Any, Any],
 )
 
 
@@ -69,7 +69,8 @@ AnyPaginatedResponse: TypeAlias = (
 
 
 class GoogleClient(
-    Generic[GetJsonResponseGoogleClient], OAuthClient[GetJsonResponseGoogleClient]
+    Generic[GetJsonResponseGoogleClient],
+    OAuthClient[GetJsonResponseGoogleClient],
 ):
     """Custom client for interacting with the Google APIs."""
 
@@ -88,13 +89,20 @@ class GoogleClient(
         url: str,
         *,
         list_key: Literal[
-            "albums", "drives", "files", "items", "mediaItems", "point"
+            "albums",
+            "drives",
+            "files",
+            "items",
+            "mediaItems",
+            "point",
         ] = "items",
-        params: dict[
-            StrBytIntFlt,
-            StrBytIntFlt | Iterable[StrBytIntFlt] | None,
-        ]
-        | None = None,
+        params: (
+            dict[
+                StrBytIntFlt,
+                StrBytIntFlt | Iterable[StrBytIntFlt] | None,
+            ]
+            | None
+        ) = None,
         method_override: Callable[..., Response] | None = None,
     ) -> list[GetJsonResponseGoogleClient]:
         """List generic items on Google's API(s).
@@ -110,18 +118,19 @@ class GoogleClient(
         Returns:
             list: a list of dicts, each representing an item from the API
         """
-
         params = (
-            {**self.DEFAULT_PARAMS, **params}
-            if params
-            else deepcopy(self.DEFAULT_PARAMS)
+            {**self.DEFAULT_PARAMS, **params} if params else deepcopy(self.DEFAULT_PARAMS)
         )
         LOGGER.info(
-            "Listing all items at endpoint `%s` with params %s", url, dumps(params)
+            "Listing all items at endpoint `%s` with params %s",
+            url,
+            dumps(params),
         )
 
         res: AnyPaginatedResponse = self._request_json_response(
-            method=method_override or get, url=url, params=params
+            method=method_override or get,
+            url=url,
+            params=params,
         )  # type: ignore[assignment]
 
         item_list: list[GetJsonResponseGoogleClient] = res[
