@@ -1,23 +1,28 @@
 """Custom client for interacting with Google's Calendar API."""
+
 from __future__ import annotations
 
 from collections.abc import Iterable
+from datetime import UTC, timedelta, tzinfo
 from datetime import date as date_
 from datetime import datetime as datetime_
-from datetime import timedelta, tzinfo
 from enum import StrEnum
-from typing import Any, ClassVar, Literal, Self, TypeAlias
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, NotRequired, Self, TypeAlias
+from zoneinfo import ZoneInfo
 
 from pydantic import Field, field_serializer, field_validator, model_validator
-from pytz import UTC, timezone
 from requests import delete
-from typing_extensions import NotRequired, TypedDict
+from typing_extensions import TypedDict
 from tzlocal import get_localzone
 
 from wg_utilities.clients._google import GoogleClient
-from wg_utilities.clients.json_api_client import StrBytIntFlt
 from wg_utilities.clients.oauth_client import BaseModelWithConfig
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable
+
+    from wg_utilities.clients.json_api_client import StrBytIntFlt
+
 
 class ResponseStatus(StrEnum):
     """Enumeration for event attendee response statuses."""
@@ -42,12 +47,13 @@ class _Attendee(BaseModelWithConfig):
     comment: str | None = None
     display_name: str | None = Field(None, alias="displayName")
     email: str
-    id: str | None = None  # noqa: A003
+    id: str | None = None
     optional: bool = False
     organizer: bool = False
     resource: bool = False
     response_status: ResponseStatus = Field(
-        alias="responseStatus", default=ResponseStatus.UNKNOWN
+        alias="responseStatus",
+        default=ResponseStatus.UNKNOWN,
     )
     self: bool = False
 
@@ -106,9 +112,8 @@ class _StartEndDatetime(BaseModelWithConfig):
         values: dict[str, Any],
     ) -> dict[str, Any]:
         """Validate that either `datetime` or `date` is provided."""
-
         values["timeZone"] = (
-            timezone(values["timeZone"]) if "timeZone" in values else get_localzone()
+            ZoneInfo(values["timeZone"]) if "timeZone" in values else get_localzone()
         )
 
         dt: date_ | None = values.get("date")
@@ -119,7 +124,8 @@ class _StartEndDatetime(BaseModelWithConfig):
 
         if dt is None:
             dttm = datetime_.strptime(
-                dttm, "%Y-%m-%dT%H:%M:%S%z"  # type: ignore[arg-type]
+                dttm,  # type: ignore[arg-type]
+                "%Y-%m-%dT%H:%M:%S%z",
             ).replace(tzinfo=values["timeZone"])
             dt = dttm.date()
         else:
@@ -134,8 +140,7 @@ class _StartEndDatetime(BaseModelWithConfig):
     @field_serializer("timezone", mode="plain", when_used="json", check_fields=True)
     def serialize_timezone(self, tz: tzinfo) -> str:
         """Serialize the timezone to a string."""
-
-        return tz.tzname(None) or ""
+        return str(tz)
 
 
 class CalendarJson(TypedDict):
@@ -160,7 +165,7 @@ class GoogleCalendarEntity(BaseModelWithConfig):
 
     description: str | None = None
     etag: str
-    id: str  # noqa: A003
+    id: str
     location: str | None = None
     summary: str
 
@@ -174,7 +179,6 @@ class GoogleCalendarEntity(BaseModelWithConfig):
         calendar: Calendar | None = None,
     ) -> Self:
         """Create a Calendar/Event from a JSON response."""
-
         value_data: dict[str, Any] = {
             "google_client": google_client,
             **value,
@@ -185,7 +189,7 @@ class GoogleCalendarEntity(BaseModelWithConfig):
 
         return cls.model_validate(value_data)
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         """Compare two GoogleCalendarEntity objects by ID."""
         if not isinstance(other, type(self)):
             return NotImplemented
@@ -204,8 +208,12 @@ class _Notification(BaseModelWithConfig):
     """Base class for Event notifications."""
 
     method: Literal["email", "sms"]
-    type: Literal[  # noqa: A003
-        "eventCreation", "eventChange", "eventCancellation", "eventResponse", "agenda"
+    type: Literal[
+        "eventCreation",
+        "eventChange",
+        "eventCancellation",
+        "eventResponse",
+        "agenda",
     ]
 
 
@@ -213,7 +221,8 @@ class Calendar(GoogleCalendarEntity):
     """Class for Google calendar instances."""
 
     access_role: Literal["freeBusyReader", "reader", "writer", "owner"] | None = Field(
-        None, alias="accessRole"
+        None,
+        alias="accessRole",
     )
     background_color: str | None = Field(None, alias="backgroundColor")
     color_id: str | None = Field(None, alias="colorId")
@@ -222,7 +231,8 @@ class Calendar(GoogleCalendarEntity):
         list[Literal["eventHangout", "eventNamedHangout", "hangoutsMeet"]],
     ] = Field(alias="conferenceProperties")
     default_reminders: list[_Reminder] = Field(
-        alias="defaultReminders", default_factory=list
+        alias="defaultReminders",
+        default_factory=list,
     )
     deleted: bool = False
     foreground_color: str | None = Field(None, alias="foregroundColor")
@@ -232,7 +242,8 @@ class Calendar(GoogleCalendarEntity):
         Literal["notifications"],
         list[_Notification],
     ] = Field(
-        alias="notificationSettings", default_factory=list  # type: ignore[assignment]
+        alias="notificationSettings",
+        default_factory=list,  # type: ignore[assignment]
     )
     primary: bool = False
     selected: bool = False
@@ -249,13 +260,12 @@ class Calendar(GoogleCalendarEntity):
         if isinstance(value, tzinfo):
             return value
 
-        return timezone(value)
+        return ZoneInfo(value)
 
     @field_serializer("timezone", mode="plain", when_used="json", check_fields=True)
     def serialize_timezone(self, tz: tzinfo) -> str:
         """Serialize the timezone to a string."""
-
-        return tz.tzname(None) or ""
+        return str(tz)
 
     def get_event_by_id(self, event_id: str) -> Event:
         """Get an event by its ID.
@@ -266,7 +276,6 @@ class Calendar(GoogleCalendarEntity):
         Returns:
             Event: Event object
         """
-
         return self.google_client.get_event_by_id(event_id, calendar=self)
 
     def get_events(
@@ -284,14 +293,14 @@ class Calendar(GoogleCalendarEntity):
         Args:
             page_size (int): the number of records to return on a single response page
             order_by (Literal["updated", "startTime"]): the order of the events
-             returned within the result
+                returned within the result
             from_datetime (datetime): lower bound (exclusive) for an event's end time
-             to filter by. Defaults to 90 days ago.
+                to filter by. Defaults to 90 days ago.
             to_datetime (datetime): upper bound (exclusive) for an event's start time
-             to filter by. Defaults to now.
+                to filter by. Defaults to now.
             combine_recurring_events (bool): whether to expand recurring events into
-             instances and only return single one-off events and instances of recurring
-             events, but not the underlying recurring events themselves
+                instances and only return single one-off events and instances of recurring
+                events, but not the underlying recurring events themselves
             day_limit (int): the maximum number of days to return events for.
 
         Returns:
@@ -306,16 +315,12 @@ class Calendar(GoogleCalendarEntity):
             "singleEvents": str(not combine_recurring_events),
         }
         if from_datetime or to_datetime or day_limit:
-            to_datetime = to_datetime or datetime_.utcnow()
-            from_datetime = from_datetime or to_datetime - timedelta(
-                days=day_limit or 90
-            )
+            to_datetime = to_datetime or datetime_.now(UTC)
+            from_datetime = from_datetime or to_datetime - timedelta(days=day_limit or 90)
 
             if day_limit is not None:
                 # Force the to_datetime to be within the day_limit
-                to_datetime = min(
-                    to_datetime, from_datetime + timedelta(days=day_limit)
-                )
+                to_datetime = min(to_datetime, from_datetime + timedelta(days=day_limit))
 
             if from_datetime.tzinfo is None:
                 from_datetime = from_datetime.replace(tzinfo=UTC)
@@ -328,7 +333,9 @@ class Calendar(GoogleCalendarEntity):
 
         return [
             Event.from_json_response(
-                item, calendar=self, google_client=self.google_client
+                item,
+                calendar=self,
+                google_client=self.google_client,
             )
             for item in self.google_client.get_items(
                 f"{self.google_client.base_url}/calendars/{self.id}/events",
@@ -405,12 +412,14 @@ class Event(GoogleCalendarEntity):
     end_time_unspecified: bool | None = Field(None, alias="endTimeUnspecified")
     event_type: EventType = Field(alias="eventType")
     extended_properties: dict[str, dict[str, str]] | None = Field(
-        None, alias="extendedProperties"
+        None,
+        alias="extendedProperties",
     )
     guests_can_invite_others: bool | None = Field(None, alias="guestsCanInviteOthers")
     guests_can_modify: bool | None = Field(None, alias="guestsCanModify")
     guests_can_see_other_guests: bool | None = Field(
-        None, alias="guestsCanSeeOtherGuests"
+        None,
+        alias="guestsCanSeeOtherGuests",
     )
     hangout_link: str | None = Field(None, alias="hangoutLink")
     html_link: str = Field(alias="htmlLink")
@@ -456,7 +465,6 @@ class Event(GoogleCalendarEntity):
 
     def __gt__(self, other: Event) -> bool:
         """Compare two events by their start time, end time, or name."""
-
         if not isinstance(other, Event):
             return NotImplemented
 
@@ -468,7 +476,6 @@ class Event(GoogleCalendarEntity):
 
     def __lt__(self, other: Event) -> bool:
         """Compare two events by their start time, end time, or name."""
-
         if not isinstance(other, Event):
             return NotImplemented
 
@@ -533,7 +540,6 @@ class GoogleCalendarClient(GoogleClient[GoogleCalendarEntityJson]):
         Raises:
             TypeError: if the start/end datetime params are not the correct type
         """
-
         calendar = calendar or self.primary_calendar
         tz = tz or str(get_localzone())
 
@@ -570,13 +576,9 @@ class GoogleCalendarClient(GoogleClient[GoogleCalendarEntityJson]):
             params={"maxResults": None},
         )
 
-        return Event.from_json_response(
-            event_json, calendar=calendar, google_client=self
-        )
+        return Event.from_json_response(event_json, calendar=calendar, google_client=self)
 
-    def delete_event_by_id(
-        self, event_id: str, calendar: Calendar | None = None
-    ) -> None:
+    def delete_event_by_id(self, event_id: str, calendar: Calendar | None = None) -> None:
         """Delete an event from a calendar.
 
         Args:
@@ -594,7 +596,10 @@ class GoogleCalendarClient(GoogleClient[GoogleCalendarEntityJson]):
         res.raise_for_status()
 
     def get_event_by_id(
-        self, event_id: str, *, calendar: Calendar | None = None
+        self,
+        event_id: str,
+        *,
+        calendar: Calendar | None = None,
     ) -> Event:
         """Get a specific event by ID.
 
@@ -640,9 +645,7 @@ class GoogleCalendarClient(GoogleClient[GoogleCalendarEntityJson]):
         """
         if not hasattr(self, "_primary_calendar"):
             self._primary_calendar = Calendar.from_json_response(
-                self.get_json_response(
-                    "/calendars/primary", params={"maxResults": None}
-                ),
+                self.get_json_response("/calendars/primary", params={"maxResults": None}),
                 google_client=self,
             )
 
