@@ -1,22 +1,25 @@
-# pylint: disable=too-many-lines
 """Custom client for interacting with Google's Drive API."""
+
 from __future__ import annotations
 
-from collections.abc import Callable, Iterable, Mapping
 from copy import deepcopy
-from datetime import date, datetime
+from datetime import date, datetime  # noqa: TC003
 from enum import StrEnum
-from pathlib import Path
 from re import sub
-from typing import Any, ClassVar, Literal, Self, TypeVar
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, Self, TypeVar
 
 from pydantic import Field, PrivateAttr, ValidationInfo, field_validator
 
 from wg_utilities.clients._google import GoogleClient
-from wg_utilities.clients.json_api_client import StrBytIntFlt
 from wg_utilities.clients.oauth_client import BaseModelWithConfig
 from wg_utilities.functions.json import JSONObj
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable, Mapping
+    from pathlib import Path
+
+    from wg_utilities.clients.json_api_client import StrBytIntFlt
+
 
 class EntityKind(StrEnum):
     """Enum for the different kinds of entities that can be returned by the API."""
@@ -71,14 +74,14 @@ class _ImageMediaMetadata(BaseModelWithConfig):
 
 class _Label(BaseModelWithConfig):
     kind: EntityKind = Field(alias="kind", default=EntityKind.LABEL)
-    id: str  # noqa: A003
+    id: str
     revision_id: str = Field(alias="revisionId")
     fields: dict[str, _LabelField]
 
 
 class _LabelField(BaseModelWithConfig):
     kind: EntityKind = Field(alias="kind", default=EntityKind.USER)
-    id: str  # noqa: A003
+    id: str
     value_type: str = Field(alias="valueType")
     date_str: list[date] = Field(alias="datestr", default_factory=list)
     integer: list[float]
@@ -96,8 +99,8 @@ class _PermissionDetails(BaseModelWithConfig):
 
 class _Permission(BaseModelWithConfig):
     kind: EntityKind = Field(alias="kind", default=EntityKind.PERMISSION)
-    id: str  # noqa: A003
-    type: str  # noqa: A003
+    id: str
+    type: str
     email_address: str | None = Field(None, alias="emailAddress")
     domain: str | None = None
     role: str
@@ -106,9 +109,7 @@ class _Permission(BaseModelWithConfig):
     display_name: str | None = Field(None, alias="displayName")
     photo_link: str | None = Field(None, alias="photoLink")
     expiration_time: datetime | None = Field(None, alias="expirationTime")
-    permission_details: _PermissionDetails | None = Field(
-        None, alias="permissionDetails"
-    )
+    permission_details: _PermissionDetails | None = Field(None, alias="permissionDetails")
     deleted: bool | None = None
     pending_owner: bool | None = Field(None, alias="pendingOwner")
 
@@ -138,13 +139,13 @@ class _ContentRestriction(BaseModelWithConfig):
     reason: str
     restricting_user: _User = Field(alias="restrictingUser")
     restriction_time: datetime = Field(alias="restrictionTime")
-    type: str  # noqa: A003
+    type: str
 
 
 class _GoogleDriveEntity(BaseModelWithConfig):
     """Base class for Google Drive entities."""
 
-    id: str  # noqa: A003
+    id: str
     name: str
     mime_type: str = Field(alias="mimeType")
 
@@ -171,7 +172,6 @@ class _GoogleDriveEntity(BaseModelWithConfig):
         Returns:
             _GoogleDriveEntity: The new instance.
         """
-
         value_data: dict[str, Any] = {
             "google_client": google_client,
             "parent_": parent,
@@ -207,7 +207,6 @@ class _GoogleDriveEntity(BaseModelWithConfig):
         Raises:
             TypeError: if the entity is not hosted on a drive
         """
-
         if isinstance(self, Drive):
             return self
 
@@ -227,11 +226,11 @@ class _GoogleDriveEntity(BaseModelWithConfig):
         parent_dir: _GoogleDriveEntity = self
 
         while hasattr(parent_dir, "parent") and (parent_dir := parent_dir.parent):
-            current_path = "/".join([parent_dir.name, current_path])
+            current_path = f"{parent_dir.name}/{current_path}"
 
         return "/" + current_path
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, type(self)):
             return NotImplemented
 
@@ -263,7 +262,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
         if not isinstance(directory, Directory):
             raise TypeError(
                 f"Cannot add `{directory.__class__.__name__}` instance to "
-                "`self.directories`."
+                "`self.directories`.",
             )
 
         if not isinstance(self._directories, list):
@@ -272,7 +271,6 @@ class _CanHaveChildren(_GoogleDriveEntity):
             self._directories.append(directory)
 
         if isinstance(self, Drive):
-            # pylint: disable=access-member-before-definition,attribute-defined-outside-init
             if not isinstance(self._all_directories, list):
                 self._all_directories = [directory]
             elif directory not in self._all_directories:
@@ -287,14 +285,13 @@ class _CanHaveChildren(_GoogleDriveEntity):
         Raises:
             TypeError: if the file is not a File
         """
-
-        if type(file) is not File:  # pylint: disable=unidiomatic-typecheck
+        if type(file) is not File:
             # This isn't an `isinstance` check because we don't want to allow
             # subclasses of `File` to be added to the list. Yes, according to the
             # Liskov substitution principle, you should be able to process a Directory
             # as a File, but that would be illogical here.
             raise TypeError(
-                f"Cannot add `{file.__class__.__name__}` instance to `self.files`."
+                f"Cannot add `{file.__class__.__name__}` instance to `self.files`.",
             )
 
         if not isinstance(self._files, list):
@@ -303,7 +300,6 @@ class _CanHaveChildren(_GoogleDriveEntity):
             self._files.append(file)
 
         if isinstance(self, Drive):
-            # pylint: disable=access-member-before-definition,attribute-defined-outside-init
             if not isinstance(self._all_files, list):
                 self._all_files = [file]
             elif file not in self._all_files:
@@ -311,7 +307,6 @@ class _CanHaveChildren(_GoogleDriveEntity):
 
     def add_child(self, child: File | Directory) -> None:
         """Add a child to this directory's children record."""
-
         if isinstance(child, Directory):
             self._add_directory(child)
         elif isinstance(child, File):
@@ -319,11 +314,10 @@ class _CanHaveChildren(_GoogleDriveEntity):
         else:
             raise TypeError(
                 f"Cannot add `{child.__class__.__name__}` instance to {self.name}'s "
-                "children."
+                "children.",
             )
 
-    def navigate(self, path: str) -> _CanHaveChildren | File:  # noqa: PLR0911
-        # pylint: disable=too-many-return-statements
+    def navigate(self, path: str) -> _CanHaveChildren | File:  # noqa: C901, PLR0911, PLR0912
         """Navigate to a directory within this directory.
 
         Args:
@@ -335,7 +329,6 @@ class _CanHaveChildren(_GoogleDriveEntity):
         Returns:
             Directory: The directory at the end of the path.
         """
-
         if "//" in path:
             raise ValueError("Path cannot contain `//`.")
 
@@ -353,7 +346,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
                 return self.navigate("/".join(rest))
             case ["..", *rest]:  # ../<potential>/<values>
                 return self.parent.navigate(  # type: ignore[attr-defined,no-any-return]
-                    "/".join(rest)
+                    "/".join(rest),
                 )
             case ["~", *rest]:  # ~/<potential>/<values>
                 return self.host_drive.navigate("/".join(rest))
@@ -364,7 +357,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
                 if drive_name != self.host_drive.name:
                     raise ValueError(
                         f"Cannot navigate to Drive {drive_name!r} from "
-                        f"`{self.host_drive.name}`."
+                        f"`{self.host_drive.name}`.",
                     )
 
                 return self.host_drive.navigate("/".join(rest))
@@ -388,8 +381,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
                         params={
                             "pageSize": "1",
                             "fields": f"files({file_fields})",
-                            "q": f"'{self.id}' in parents and name = "
-                            f"'{directory_name}'",
+                            "q": f"'{self.id}' in parents and name = '{directory_name}'",
                         },
                     ).pop()
                 except IndexError:
@@ -441,10 +433,9 @@ class _CanHaveChildren(_GoogleDriveEntity):
         Returns:
             str: the full directory tree in text form
         """
-
         if not local_only:
             self.host_drive.map(
-                map_type=EntityType.FILE if include_files else EntityType.DIRECTORY
+                map_type=EntityType.FILE if include_files else EntityType.DIRECTORY,
             )
 
         output = self.name
@@ -462,7 +453,6 @@ class _CanHaveChildren(_GoogleDriveEntity):
                 block_pipes_at_levels (list): a list of levels to block further
                     pipes at
             """
-
             nonlocal output
 
             # Creating a deep copy means that when we go back up from the recursion,
@@ -527,7 +517,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
         Returns:
             list[Directory | File]: The list of children.
         """
-        # TODO needs a check to avoid requesting every time
+        # TODO: needs a check to avoid requesting every time
         self.reset_known_children()
         return self.files + self.directories  # type: ignore[operator]
 
@@ -538,9 +528,8 @@ class _CanHaveChildren(_GoogleDriveEntity):
         Returns:
             list: the directories contained within this directory
         """
-
         if self._directories_loaded is not True:
-            # TODO replace these with a `file_fields` property
+            # TODO: replace these with a `file_fields` property
             file_fields = (
                 "*"
                 if self.google_client.item_metadata_retrieval == IMR.ON_INIT
@@ -569,7 +558,7 @@ class _CanHaveChildren(_GoogleDriveEntity):
                             "fields": f"nextPageToken, files({file_fields})",
                         },
                     )
-                ]
+                ],
             )
 
             self._directories_loaded = True
@@ -625,10 +614,12 @@ class File(_GoogleDriveEntity):
     capabilities: _DriveCapabilities | None = None
     content_hints: _ContentHints | None = Field(None, alias="contentHints")
     content_restrictions: list[_ContentRestriction] | None = Field(
-        None, alias="contentRestrictions"
+        None,
+        alias="contentRestrictions",
     )
     copy_requires_writer_permission: bool | None = Field(
-        None, alias="copyRequiresWriterPermission"
+        None,
+        alias="copyRequiresWriterPermission",
     )
     created_time: datetime | None = Field(None, alias="createdTime")
     description: str | None = None
@@ -638,22 +629,23 @@ class File(_GoogleDriveEntity):
     folder_color_rgb: str | None = Field(None, alias="folderColorRgb")
     file_extension: str | None = Field(None, alias="fileExtension")
     full_file_extension: str | None = Field(None, alias="fullFileExtension")
-    has_augmented_permissions: bool | None = Field(
-        None, alias="hasAugmentedPermissions"
-    )
+    has_augmented_permissions: bool | None = Field(None, alias="hasAugmentedPermissions")
     has_thumbnail: bool | None = Field(None, alias="hasThumbnail")
     head_revision_id: str | None = Field(None, alias="headRevisionId")
     icon_link: str | None = Field(None, alias="iconLink")
     image_media_metadata: _ImageMediaMetadata | None = Field(
-        None, alias="imageMediaMetadata"
+        None,
+        alias="imageMediaMetadata",
     )
     is_app_authorized: bool | None = Field(None, alias="isAppAuthorized")
     label_info: dict[Literal["labels"], list[_Label]] = Field(
-        alias="labelInfo", default_factory=dict
+        alias="labelInfo",
+        default_factory=dict,
     )
     last_modifying_user: _User | None = Field(None, alias="lastModifyingUser")
     link_share_metadata: dict[
-        Literal["securityUpdateEligible", "securityUpdateEnabled"], bool
+        Literal["securityUpdateEligible", "securityUpdateEnabled"],
+        bool,
     ] = Field(alias="linkShareMetadata", default_factory=dict)
     md5_checksum: str | None = Field(None, alias="md5Checksum")
     modified_by_me: bool | None = Field(None, alias="modifiedByMe")
@@ -691,7 +683,8 @@ class File(_GoogleDriveEntity):
     trashing_user: _User | None = Field(None, alias="trashingUser")
     version: int | None = None
     video_media_metadata: _VideoMediaMetadata | None = Field(
-        None, alias="videoMediaMetadata"
+        None,
+        alias="videoMediaMetadata",
     )
     viewed_by_me: bool | None = Field(None, alias="viewedByMe")
     viewed_by_me_time: datetime | None = Field(None, alias="viewedByMeTime")
@@ -713,7 +706,6 @@ class File(_GoogleDriveEntity):
         Returns:
             Any: The value of the attribute.
         """
-
         # If the attribute isn't a field, just return the value
         if (
             name in ("model_fields", "model_fields_set")
@@ -761,7 +753,9 @@ class File(_GoogleDriveEntity):
     @field_validator("parent_")
     @classmethod
     def _validate_parent_instance(
-        cls, value: Directory | Drive | None, info: ValidationInfo
+        cls,
+        value: Directory | Drive | None,
+        info: ValidationInfo,
     ) -> Directory | Drive | None:
         """Validate that the parent instance's ID matches the expected parent ID.
 
@@ -776,13 +770,12 @@ class File(_GoogleDriveEntity):
             ValueError: If the parent instance's ID doesn't match the expected parent
                 ID.
         """
-
         if value is None:
             return value
 
         if value.id != info.data["parents"][0]:
             raise ValueError(
-                f"Parent ID mismatch: {value.id} != {info.data['parents'][0]}"
+                f"Parent ID mismatch: {value.id} != {info.data['parents'][0]}",
             )
 
         return value
@@ -792,7 +785,7 @@ class File(_GoogleDriveEntity):
 
         Args:
             force_update (bool): re-pull the description from Google Drive, even if we
-             already have the description locally
+                already have the description locally
 
         Returns:
             dict: the description JSON for this file
@@ -800,7 +793,6 @@ class File(_GoogleDriveEntity):
         Raises:
             ValueError: if an unexpected field is returned from the Google Drive API.
         """
-
         if (
             force_update
             or not hasattr(self, "_description")
@@ -820,7 +812,7 @@ class File(_GoogleDriveEntity):
                 except ValueError as exc:
                     raise ValueError(
                         f"Received unexpected field {key!r} with value {value!r}"
-                        " from Google Drive API"
+                        " from Google Drive API",
                     ) from exc
 
         return self._description
@@ -858,13 +850,14 @@ class File(_GoogleDriveEntity):
 class Directory(File, _CanHaveChildren):
     """A Google Drive directory - basically a File with extended functionality."""
 
-    MIME_TYPE: ClassVar[
-        Literal["application/vnd.google-apps.folder"]
-    ] = "application/vnd.google-apps.folder"
+    MIME_TYPE: ClassVar[Literal["application/vnd.google-apps.folder"]] = (
+        "application/vnd.google-apps.folder"
+    )
 
     kind: Literal[EntityKind.DIRECTORY] = Field(default=EntityKind.DIRECTORY)
     mime_type: Literal["application/vnd.google-apps.folder"] = Field(
-        alias="mimeType", default=MIME_TYPE
+        alias="mimeType",
+        default=MIME_TYPE,
     )
 
     host_drive_: Drive = Field(exclude=True)
@@ -873,7 +866,6 @@ class Directory(File, _CanHaveChildren):
     @classmethod
     def _validate_kind(cls, value: str | None) -> str:
         """Set the kind to "drive#folder"."""
-
         # Directories are just a subtype of files, so `"drive#file"` is okay too
         if value not in (EntityKind.DIRECTORY, EntityKind.FILE):
             raise ValueError(f"Invalid kind for Directory: {value}")
@@ -884,7 +876,6 @@ class Directory(File, _CanHaveChildren):
     @classmethod
     def _validate_mime_type(cls, mime_type: str) -> str:
         """Just an override for the parent class's validator."""
-
         return mime_type
 
     def __repr__(self) -> str:
@@ -896,29 +887,37 @@ class _DriveCapabilities(BaseModelWithConfig):
     can_accept_ownership: bool | None = Field(None, alias="canAcceptOwnership")
     can_add_children: bool | None = Field(None, alias="canAddChildren")
     can_add_folder_from_another_drive: bool | None = Field(
-        None, alias="canAddFolderFromAnotherDrive"
+        None,
+        alias="canAddFolderFromAnotherDrive",
     )
     can_add_my_drive_parent: bool | None = Field(None, alias="canAddMyDriveParent")
     can_change_copy_requires_writer_permission: bool | None = Field(
-        None, alias="canChangeCopyRequiresWriterPermission"
+        None,
+        alias="canChangeCopyRequiresWriterPermission",
     )
     can_change_copy_requires_writer_permission_restriction: bool | None = Field(
-        None, alias="canChangeCopyRequiresWriterPermissionRestriction"
+        None,
+        alias="canChangeCopyRequiresWriterPermissionRestriction",
     )
     can_change_domain_users_only_restriction: bool | None = Field(
-        None, alias="canChangeDomainUsersOnlyRestriction"
+        None,
+        alias="canChangeDomainUsersOnlyRestriction",
     )
     can_change_drive_background: bool | None = Field(
-        None, alias="canChangeDriveBackground"
+        None,
+        alias="canChangeDriveBackground",
     )
     can_change_drive_members_only_restriction: bool | None = Field(
-        None, alias="canChangeDriveMembersOnlyRestriction"
+        None,
+        alias="canChangeDriveMembersOnlyRestriction",
     )
     can_change_security_update_enabled: bool | None = Field(
-        None, alias="canChangeSecurityUpdateEnabled"
+        None,
+        alias="canChangeSecurityUpdateEnabled",
     )
     can_change_viewers_can_copy_content: bool | None = Field(
-        None, alias="canChangeViewersCanCopyContent"
+        None,
+        alias="canChangeViewersCanCopyContent",
     )
     can_comment: bool | None = Field(None, alias="canComment")
     can_copy: bool | None = Field(None, alias="canCopy")
@@ -931,33 +930,34 @@ class _DriveCapabilities(BaseModelWithConfig):
     can_manage_members: bool | None = Field(None, alias="canManageMembers")
     can_modify_content: bool | None = Field(None, alias="canModifyContent")
     can_modify_content_restriction: bool | None = Field(
-        None, alias="canModifyContentRestriction"
+        None,
+        alias="canModifyContentRestriction",
     )
     can_modify_labels: bool | None = Field(None, alias="canModifyLabels")
     can_move_children_out_of_drive: bool | None = Field(
-        None, alias="canMoveChildrenOutOfDrive"
+        None,
+        alias="canMoveChildrenOutOfDrive",
     )
     can_move_children_within_drive: bool | None = Field(
-        None, alias="canMoveChildrenWithinDrive"
+        None,
+        alias="canMoveChildrenWithinDrive",
     )
     can_move_item_into_team_drive: bool | None = Field(
-        None, alias="canMoveItemIntoTeamDrive"
+        None,
+        alias="canMoveItemIntoTeamDrive",
     )
     can_move_item_out_of_drive: bool | None = Field(None, alias="canMoveItemOutOfDrive")
-    can_move_item_within_drive: bool | None = Field(
-        None, alias="canMoveItemWithinDrive"
-    )
+    can_move_item_within_drive: bool | None = Field(None, alias="canMoveItemWithinDrive")
     can_read_labels: bool | None = Field(None, alias="canReadLabels")
     can_read_revisions: bool | None = Field(None, alias="canReadRevisions")
     can_read_drive: bool | None = Field(None, alias="canReadDrive")
     can_remove_children: bool | None = Field(None, alias="canRemoveChildren")
-    can_remove_my_drive_parent: bool | None = Field(
-        None, alias="canRemoveMyDriveParent"
-    )
+    can_remove_my_drive_parent: bool | None = Field(None, alias="canRemoveMyDriveParent")
     can_rename: bool | None = Field(None, alias="canRename")
     can_rename_drive: bool | None = Field(None, alias="canRenameDrive")
     can_reset_drive_restrictions: bool | None = Field(
-        None, alias="canResetDriveRestrictions"
+        None,
+        alias="canResetDriveRestrictions",
     )
     can_share: bool | None = Field(None, alias="canShare")
     can_trash: bool | None = Field(None, alias="canTrash")
@@ -973,7 +973,7 @@ class _DriveRestrictions(BaseModelWithConfig):
 
 
 class _DriveBackgroundImageFile(BaseModelWithConfig):
-    id: str  # noqa: A003
+    id: str
     x_coordinate: float = Field(alias="xCoordinate")
     y_coordinate: float = Field(alias="yCoordinate")
     width: float
@@ -987,18 +987,21 @@ class Drive(_CanHaveChildren):
 
     kind: Literal[EntityKind.DRIVE] = Field(default=EntityKind.DRIVE)
     mime_type: Literal["application/vnd.google-apps.folder"] = Field(
-        alias="mimeType", default=Directory.MIME_TYPE
+        alias="mimeType",
+        default=Directory.MIME_TYPE,
     )
 
     # Optional, can be retrieved with the `describe` method or by getting the attribute
     background_image_file: _DriveBackgroundImageFile | None = Field(
-        None, alias="backgroundImageFile"
+        None,
+        alias="backgroundImageFile",
     )
     background_image_link: str | None = Field(None, alias="backgroundImageLink")
     capabilities: _DriveCapabilities | None = None
     color_rgb: str | None = Field(None, alias="colorRgb")
     copy_requires_writer_permission: bool | None = Field(
-        None, alias="copyRequiresWriterPermission"
+        None,
+        alias="copyRequiresWriterPermission",
     )
     created_time: datetime | None = Field(None, alias="createdTime")
     explicitly_trashed: bool | None = Field(None, alias="explicitlyTrashed")
@@ -1009,7 +1012,8 @@ class Drive(_CanHaveChildren):
     is_app_authorized: bool | None = Field(None, alias="isAppAuthorized")
     last_modifying_user: _User | None = Field(None, alias="lastModifyingUser")
     link_share_metadata: dict[
-        Literal["securityUpdateEligible", "securityUpdateEnabled"], bool
+        Literal["securityUpdateEligible", "securityUpdateEnabled"],
+        bool,
     ] = Field(alias="linkShareMetadata", default_factory=dict)
     modified_by_me: bool | None = Field(None, alias="modifiedByMe")
     modified_by_me_time: datetime | None = Field(None, alias="modifiedByMeTime")
@@ -1045,7 +1049,6 @@ class Drive(_CanHaveChildren):
     @classmethod
     def _validate_kind(cls, value: str | None) -> str:
         """Set the kind to "drive#drive"."""
-
         # Drives are just a subtype of files, so `"drive#file"` is okay too
         if value not in (EntityKind.DRIVE, EntityKind.FILE):
             raise ValueError(f"Invalid kind for Drive: {value}")
@@ -1053,7 +1056,9 @@ class Drive(_CanHaveChildren):
         return EntityKind.DRIVE
 
     def _get_entity_by_id(
-        self, cls: type[DriveSubEntity], entity_id: str
+        self,
+        cls: type[DriveSubEntity],
+        entity_id: str,
     ) -> DriveSubEntity:
         """Get either a Directory or File by its ID.
 
@@ -1088,9 +1093,6 @@ class Drive(_CanHaveChildren):
 
         Returns:
             Directory: the directory with the given ID
-
-        Raises:
-            ResourceNotFoundError: if a directory with the given ID does not exist
         """
         if isinstance(self._all_directories, list):
             for directory in self._all_directories:
@@ -1107,9 +1109,6 @@ class Drive(_CanHaveChildren):
 
         Returns:
             File: the file with the given ID
-
-        Raises:
-            ResourceNotFoundError: if a file with the given ID does not exist
         """
         if isinstance(self._all_files, list):
             for file in self._all_files:
@@ -1118,14 +1117,13 @@ class Drive(_CanHaveChildren):
 
         return self._get_entity_by_id(File, file_id)
 
-    def map(self, map_type: EntityType = EntityType.FILE) -> None:  # noqa: A003
+    def map(self, map_type: EntityType = EntityType.FILE) -> None:  # noqa: C901
         """Traverse the entire Drive to map its content.
 
         Args:
             map_type (EntityType, optional): the type of entity to map. Defaults to
                 EntityType.FILE.
         """
-
         if (map_type == EntityType.DIRECTORY and self._directories_mapped is True) or (
             map_type == EntityType.FILE and self._files_mapped is True
         ):
@@ -1253,7 +1251,6 @@ class Drive(_CanHaveChildren):
         Raises:
             ValueError: if the given entity type is not supported
         """
-
         file_fields = (
             "*"
             if self.google_client.item_metadata_retrieval == IMR.ON_INIT
@@ -1327,7 +1324,6 @@ class Drive(_CanHaveChildren):
     @property
     def all_directories(self) -> list[Directory]:
         """Get all directories in the Drive."""
-
         if self._directories_mapped is not True:
             self.map(map_type=EntityType.DIRECTORY)
 
@@ -1336,7 +1332,6 @@ class Drive(_CanHaveChildren):
     @property
     def all_files(self) -> list[File]:
         """Get all files in the Drive."""
-
         if self._files_mapped is not True:
             self.map()
 
@@ -1404,6 +1399,7 @@ class GoogleDriveClient(GoogleClient[JSONObj]):
         oauth_redirect_uri_override: str | None = None,
         headless_auth_link_callback: Callable[[str], None] | None = None,
         use_existing_credentials_only: bool = False,
+        validate_request_success: bool = True,
         item_metadata_retrieval: IMR = IMR.ON_FIRST_REQUEST,
     ):
         super().__init__(
@@ -1418,6 +1414,7 @@ class GoogleDriveClient(GoogleClient[JSONObj]):
             headless_auth_link_callback=headless_auth_link_callback,
             use_existing_credentials_only=use_existing_credentials_only,
             base_url=self.BASE_URL,
+            validate_request_success=validate_request_success,
         )
 
         self.item_metadata_retrieval = item_metadata_retrieval
@@ -1432,7 +1429,8 @@ class GoogleDriveClient(GoogleClient[JSONObj]):
         if not hasattr(self, "_my_drive"):
             self._my_drive = Drive.from_json_response(
                 self.get_json_response(
-                    "/files/root", params={"fields": "*", "pageSize": None}
+                    "/files/root",
+                    params={"fields": "*", "pageSize": None},
                 ),
                 google_client=self,
             )
@@ -1452,7 +1450,9 @@ class GoogleDriveClient(GoogleClient[JSONObj]):
                 google_client=self,
             )
             for drive in self.get_items(
-                "/drives", list_key="drives", params={"fields": "*"}
+                "/drives",
+                list_key="drives",
+                params={"fields": "*"},
             )
         ]
 
