@@ -1,7 +1,8 @@
 """Custom client for interacting with Google's Photos API."""
+
 from __future__ import annotations
 
-from datetime import datetime
+from datetime import datetime  # noqa: TC003
 from enum import Enum
 from logging import DEBUG, getLogger
 from pathlib import Path
@@ -14,11 +15,9 @@ from typing_extensions import TypedDict
 from wg_utilities.clients._google import GoogleClient
 from wg_utilities.clients.oauth_client import BaseModelWithConfig
 from wg_utilities.functions import force_mkdir
-from wg_utilities.loggers import add_stream_handler
 
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
-add_stream_handler(LOGGER)
 
 
 class _SharedAlbumOptionsInfo(TypedDict):
@@ -77,7 +76,7 @@ class _GooglePhotosEntityJson(TypedDict):
 class GooglePhotosEntity(BaseModelWithConfig):
     """Generic base class for Google Photos entities."""
 
-    id: str  # noqa: A003
+    id: str
     product_url: str = Field(alias="productUrl")
 
     google_client: GooglePhotosClient = Field(exclude=True)
@@ -90,7 +89,6 @@ class GooglePhotosEntity(BaseModelWithConfig):
         google_client: GooglePhotosClient,
     ) -> Self:
         """Create an entity from a JSON response."""
-
         value_data: dict[str, Any] = {
             "google_client": google_client,
             **value,
@@ -102,11 +100,11 @@ class GooglePhotosEntity(BaseModelWithConfig):
 class AlbumJson(_GooglePhotosEntityJson):
     """JSON representation of an Album."""
 
-    coverPhotoBaseUrl: str  # noqa: N815
-    coverPhotoMediaItemId: str  # noqa: N815
-    isWriteable: bool | None  # noqa: N815
-    mediaItemsCount: int  # noqa: N815
-    shareInfo: _ShareInfoInfo | None  # noqa: N815
+    coverPhotoBaseUrl: str
+    coverPhotoMediaItemId: str
+    isWriteable: bool | None
+    mediaItemsCount: int
+    shareInfo: _ShareInfoInfo | None
     title: str
 
 
@@ -126,7 +124,6 @@ class Album(GooglePhotosEntity):
     @classmethod
     def _validate_title(cls, value: str) -> str:
         """Validate the title of the album."""
-
         if not value:
             raise ValueError("Album title cannot be empty.")
 
@@ -140,7 +137,6 @@ class Album(GooglePhotosEntity):
         Returns:
             list: a list of MediaItem instances, representing the contents of the album
         """
-
         if not hasattr(self, "_media_items"):
             self._media_items = [
                 MediaItem.from_json_response(item, google_client=self.google_client)
@@ -156,28 +152,25 @@ class Album(GooglePhotosEntity):
 
     def __contains__(self, item: MediaItem) -> bool:
         """Check if the album contains the given media item."""
-
         return item.id in [media_item.id for media_item in self.media_items]
 
 
 class MediaItemJson(_GooglePhotosEntityJson):
     """JSON representation of a Media Item (photo or video)."""
 
-    baseUrl: str  # noqa: N815
-    contributorInfo: dict[str, str] | None  # noqa: N815
+    baseUrl: str
+    contributorInfo: dict[str, str] | None
     description: str | None
     filename: str
-    mediaMetadata: _MediaItemMetadata  # noqa: N815
-    mimeType: str  # noqa: N815
+    mediaMetadata: _MediaItemMetadata
+    mimeType: str
 
 
 class MediaItem(GooglePhotosEntity):
     """Class for representing a MediaItem and its metadata/content."""
 
     base_url: str = Field(alias="baseUrl")
-    contributor_info: dict[str, str] | None = Field(
-        alias="contributorInfo", default=None
-    )
+    contributor_info: dict[str, str] | None = Field(alias="contributorInfo", default=None)
     description: str | None = Field(default=None)
     filename: str
     media_metadata: _MediaItemMetadata = Field(alias="mediaMetadata")
@@ -185,13 +178,28 @@ class MediaItem(GooglePhotosEntity):
 
     _local_path: Path
 
+    def as_bytes(self, *, height_override: int = 0, width_override: int = 0) -> bytes:
+        """MediaItem binary content - without the download."""
+        height = height_override or self.height
+        width = width_override or self.width
+
+        param_str = {
+            MediaType.IMAGE: f"=w{width}-h{height}",
+            MediaType.VIDEO: "=dv",
+        }.get(self.media_type, "")
+
+        return self.google_client._get(
+            f"{self.base_url}{param_str}",
+            params={"pageSize": None},
+        ).content
+
     def download(
         self,
         target_directory: Path | str = "",
         *,
         file_name_override: str | None = None,
-        width_override: int | None = None,
-        height_override: int | None = None,
+        width_override: int = 0,
+        height_override: int = 0,
         force_download: bool = False,
     ) -> Path:
         """Download the media item to local storage.
@@ -209,9 +217,8 @@ class MediaItem(GooglePhotosEntity):
                 locally already
 
         Returns:
-             str: the path to the downloaded file (self.local_path)
+                str: the path to the downloaded file (self.local_path)
         """
-
         if isinstance(target_directory, str):
             target_directory = (
                 Path.cwd() if target_directory == "" else Path(target_directory)
@@ -230,18 +237,11 @@ class MediaItem(GooglePhotosEntity):
                 self.local_path,
             )
         else:
-            width = width_override or self.width
-            height = height_override or self.height
-
-            param_str = {
-                MediaType.IMAGE: f"=w{width}-h{height}",
-                MediaType.VIDEO: "=dv",
-            }.get(self.media_type, "")
-
             force_mkdir(self.local_path, path_is_file=True).write_bytes(
-                self.google_client._get(  # pylint: disable=protected-access
-                    f"{self.base_url}{param_str}", params={"pageSize": None}
-                ).content
+                self.as_bytes(
+                    width_override=width_override,
+                    height_override=height_override,
+                ),
             )
 
         return self.local_path
@@ -322,8 +322,7 @@ class GooglePhotosClient(GoogleClient[GooglePhotosEntityJson]):
     """Custom client for interacting with the Google Photos API.
 
     See Also:
-        GoogleClient: the base Google client, used for authentication and common
-         functions
+        GoogleClient: the base Google client, used for authentication and common functions
     """
 
     BASE_URL = "https://photoslibrary.googleapis.com/v1"
@@ -349,7 +348,6 @@ class GooglePhotosClient(GoogleClient[GooglePhotosEntityJson]):
         Returns:
             Album: the album with the given ID
         """
-
         if hasattr(self, "_albums"):
             for album in self._albums:
                 if album.id == album_id:
@@ -379,7 +377,6 @@ class GooglePhotosClient(GoogleClient[GooglePhotosEntityJson]):
         Raises:
             FileNotFoundError: if the client can't find an album with the correct name
         """
-
         LOGGER.info("Getting metadata for album `%s`", album_name)
         for album in self.albums:
             if album.title == album_name:
@@ -394,7 +391,6 @@ class GooglePhotosClient(GoogleClient[GooglePhotosEntityJson]):
         Returns:
             list: a list of Album instances
         """
-
         if not hasattr(self, "_albums"):
             self._albums = [
                 Album.from_json_response(item, google_client=self)
@@ -416,7 +412,7 @@ class GooglePhotosClient(GoogleClient[GooglePhotosEntityJson]):
                         params={"pageSize": 50},
                     )
                     if item["id"] not in album_ids
-                ]
+                ],
             )
 
             self._album_count = len(self._albums)
