@@ -1,19 +1,23 @@
 """Custom client for interacting with Monzo's API."""
+
 from __future__ import annotations
 
-from collections.abc import Iterable
-from datetime import datetime, timedelta
+from datetime import UTC, datetime, timedelta
 from logging import DEBUG, getLogger
-from typing import Any, ClassVar, Literal, final
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, final
 
 from pydantic import Field, field_validator
 from requests import put
 from typing_extensions import TypedDict
 
-from wg_utilities.clients.json_api_client import StrBytIntFlt
 from wg_utilities.clients.oauth_client import BaseModelWithConfig, OAuthClient
 from wg_utilities.functions import DTU, cleanse_string, utcnow
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable
+
+    from wg_utilities.clients.json_api_client import StrBytIntFlt
+
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
 
@@ -77,9 +81,12 @@ class PotJson(TypedDict):
 TransactionCategory = Literal[
     "bills",
     "cash",
+    "charity",
     "eating_out",
     "entertainment",
+    "expenses",
     "general",
+    "gifts",
     "groceries",
     "holidays",
     "income",
@@ -114,7 +121,7 @@ class TransactionJson(TypedDict):
     ]
     category: TransactionCategory
     counterparty: dict[str, str]
-    created: str
+    created: datetime
     currency: str
     decline_reason: str | None
     dedupe_id: str
@@ -128,6 +135,7 @@ class TransactionJson(TypedDict):
     local_amount: int
     local_currency: str
     merchant: str | None
+    merchant_feedback_uri: str | None
     metadata: dict[str, str]
     notes: str
     originator: bool
@@ -135,7 +143,7 @@ class TransactionJson(TypedDict):
     scheme: str
     settled: str
     tab: dict[str, object] | None
-    updated: str
+    updated: datetime
     user_id: str
 
 
@@ -152,19 +160,16 @@ class Transaction(BaseModelWithConfig):
     can_be_made_subscription: bool
     can_match_transactions_in_categorization: bool
     can_split_the_bill: bool
-    categories: dict[
-        TransactionCategory,
-        int,
-    ]
+    categories: dict[TransactionCategory, int]
     category: TransactionCategory
     counterparty: dict[str, str]
-    created: str
+    created: datetime
     currency: str
     decline_reason: str | None = None
     dedupe_id: str
     description: str
     fees: dict[str, Any] | None = None
-    id: str  # noqa: A003
+    id: str
     include_in_spending: bool
     international: bool | None = None
     is_load: bool
@@ -172,6 +177,7 @@ class Transaction(BaseModelWithConfig):
     local_amount: int
     local_currency: str
     merchant: str | None
+    merchant_feedback_uri: str | None = None
     metadata: dict[str, str]
     notes: str
     originator: bool
@@ -179,7 +185,7 @@ class Transaction(BaseModelWithConfig):
     scheme: str
     settled: str
     tab: dict[str, object] | None = None
-    updated: str
+    updated: datetime
     user_id: str
 
 
@@ -216,21 +222,22 @@ class Account(BaseModelWithConfig):
     created: datetime
     currency: Literal["GBP"]
     description: str
-    id: str  # noqa: A003
+    id: str
     initial_balance: int | None = Field(None, validation_alias="balance")
     initial_balance_including_flexible_savings: int | None = Field(
-        None, validation_alias="balance_including_flexible_savings"
+        None,
+        validation_alias="balance_including_flexible_savings",
     )
     initial_spend_today: int | None = Field(None, validation_alias="spend_today")
     initial_total_balance: int | None = Field(None, validation_alias="total_balance")
     owners: list[AccountOwner]
     payment_details: dict[str, dict[str, str]] | None = None
     sort_code: str = Field(min_length=6, max_length=6)
-    type: Literal["uk_monzo_flex", "uk_retail", "uk_retail_joint"]  # noqa: A003
+    type: Literal["uk_monzo_flex", "uk_retail", "uk_retail_joint"]
 
     monzo_client: MonzoClient = Field(exclude=True)
     balance_update_threshold: int = Field(15, exclude=True)
-    last_balance_update: datetime = Field(datetime(1970, 1, 1), exclude=True)
+    last_balance_update: datetime = Field(datetime(1970, 1, 1, tzinfo=UTC), exclude=True)
     _balance_variables: BalanceVariables
 
     @field_validator("sort_code", mode="before")
@@ -240,7 +247,6 @@ class Account(BaseModelWithConfig):
 
         Represented as a string so leading zeroes aren't lost.
         """
-
         if isinstance(sort_code, int):
             sort_code = str(sort_code)
 
@@ -259,7 +265,6 @@ class Account(BaseModelWithConfig):
         monzo_client: MonzoClient,
     ) -> Account:
         """Create an account from a JSON response."""
-
         value_data: dict[str, Any] = {
             "monzo_client": monzo_client,
             **value,
@@ -286,9 +291,13 @@ class Account(BaseModelWithConfig):
         Returns:
             list[dict[str, object]]: the list of transactions
         """
-
-        from_datetime = from_datetime or datetime.utcnow() - timedelta(days=89)
-        to_datetime = to_datetime or datetime.utcnow()
+        from_datetime = (
+            from_datetime or (datetime.now(UTC) - timedelta(days=89))
+        ).replace(microsecond=0, tzinfo=None)
+        to_datetime = (to_datetime or datetime.now(UTC)).replace(
+            microsecond=0,
+            tzinfo=None,
+        )
 
         return [
             Transaction(**item)
@@ -311,19 +320,16 @@ class Account(BaseModelWithConfig):
         `balance_update_threshold` minutes ago, or if it is None. Can also be called
         manually if required.
         """
-
         if not hasattr(self, "_balance_variables") or self.last_balance_update <= (
-            datetime.utcnow() - timedelta(minutes=self.balance_update_threshold)
+            datetime.now(UTC) - timedelta(minutes=self.balance_update_threshold)
         ):
-            LOGGER.debug(
-                "Balance variable update threshold crossed, getting new values"
-            )
+            LOGGER.debug("Balance variable update threshold crossed, getting new values")
 
             self._balance_variables = BalanceVariables.model_validate(
-                self.monzo_client.get_json_response(f"/balance?account_id={self.id}")
+                self.monzo_client.get_json_response(f"/balance?account_id={self.id}"),
             )
 
-            self.last_balance_update = datetime.utcnow()
+            self.last_balance_update = datetime.now(UTC)
 
     @property
     def balance(self) -> int | None:
@@ -351,7 +357,7 @@ class Account(BaseModelWithConfig):
 
         Returns:
             float: the currently available balance of the account, including flexible
-             savings pots
+                savings pots
         """
         return self.balance_variables.balance_including_flexible_savings
 
@@ -371,7 +377,7 @@ class Account(BaseModelWithConfig):
 
         Returns:
             str: the sum of the currently available balance of the account and the
-             combined total of all the user's pots
+                combined total of all the user's pots
         """
         return self.balance_variables.total_balance
 
@@ -400,7 +406,7 @@ class Pot(BaseModelWithConfig):
     deleted: bool
     goal_amount: float | None = None
     has_virtual_cards: bool
-    id: str  # noqa: A003
+    id: str
     is_tax_pot: bool
     isa_wrapper: str
     lock_type: Literal["until_date"] | None = None
@@ -411,7 +417,7 @@ class Pot(BaseModelWithConfig):
     round_up: bool
     round_up_multiplier: float | None = None
     style: str
-    type: str  # noqa: A003
+    type: str
     updated: datetime
 
 
@@ -437,7 +443,10 @@ class MonzoClient(OAuthClient[MonzoGJR]):
     _current_account: Account
 
     def deposit_into_pot(
-        self, pot: Pot, amount_pence: int, dedupe_id: str | None = None
+        self,
+        pot: Pot,
+        amount_pence: int,
+        dedupe_id: str | None = None,
     ) -> None:
         """Move money from the user's account into one of their pots.
 
@@ -445,11 +454,10 @@ class MonzoClient(OAuthClient[MonzoGJR]):
             pot (Pot): the target pot
             amount_pence (int): the amount of money to deposit, in pence
             dedupe_id (str): unique string used to de-duplicate deposits. Will be
-             created if not provided
+                created if not provided
         """
-
         dedupe_id = dedupe_id or "|".join(
-            [pot.id, str(amount_pence), str(utcnow(DTU.SECOND))]
+            [pot.id, str(amount_pence), str(utcnow(DTU.SECOND))],
         )
 
         res = put(
@@ -465,21 +473,24 @@ class MonzoClient(OAuthClient[MonzoGJR]):
         res.raise_for_status()
 
     def list_accounts(
-        self, *, include_closed: bool = False, account_type: str | None = None
+        self,
+        *,
+        include_closed: bool = False,
+        account_type: str | None = None,
     ) -> list[Account]:
         """Get a list of the user's accounts.
 
         Args:
             include_closed (bool): whether to include closed accounts in the response
             account_type (str): the type of account(s) to find; submitted as param in
-             request
+                request
 
         Returns:
             list: Account instances, containing all related info
         """
-
         res = self.get_json_response(
-            "/accounts", params={"account_type": account_type} if account_type else None
+            "/accounts",
+            params={"account_type": account_type} if account_type else None,
         )
 
         return [
@@ -497,9 +508,9 @@ class MonzoClient(OAuthClient[MonzoGJR]):
         Returns:
             list: Pot instances, containing all related info
         """
-
         res = self.get_json_response(
-            "/pots", params={"current_account_id": self.current_account.id}
+            "/pots",
+            params={"current_account_id": self.current_account.id},
         )
 
         return [
@@ -524,14 +535,19 @@ class MonzoClient(OAuthClient[MonzoGJR]):
         return None
 
     def get_pot_by_name(
-        self, pot_name: str, *, exact_match: bool = False
+        self,
+        pot_name: str,
+        *,
+        exact_match: bool = False,
+        include_deleted: bool = False,
     ) -> Pot | None:
         """Get a pot from its name.
 
         Args:
             pot_name (str): the name of the pot to find
             exact_match (bool): if False, all pot names will be cleansed before
-             evaluation
+                evaluation
+            include_deleted (bool): whether to include deleted pots in the response
 
         Returns:
             Pot: the Pot instance
@@ -539,7 +555,7 @@ class MonzoClient(OAuthClient[MonzoGJR]):
         if not exact_match:
             pot_name = cleanse_string(pot_name)
 
-        for pot in self.list_pots(include_deleted=True):
+        for pot in self.list_pots(include_deleted=include_deleted):
             found_name = pot.name if exact_match else cleanse_string(pot.name)
             if found_name.lower() == pot_name.lower():
                 return pot
