@@ -1,7 +1,7 @@
 """Generic OAuth client to allow for reusable authentication flows/checks etc."""
+
 from __future__ import annotations
 
-from collections.abc import Callable
 from datetime import datetime
 from json import dumps
 from logging import DEBUG, getLogger
@@ -23,6 +23,8 @@ from wg_utilities.functions import user_data_dir
 from wg_utilities.functions.file_management import force_mkdir
 
 if TYPE_CHECKING:  # pragma: no cover
+    from collections.abc import Callable
+
     from pydantic.main import IncEx
 
 else:
@@ -35,26 +37,27 @@ LOGGER.setLevel(DEBUG)
 class BaseModelWithConfig(BaseModel):
     """Reusable `BaseModel` with Config to apply to all subclasses."""
 
-    model_config: ClassVar[ConfigDict] = {
-        "arbitrary_types_allowed": True,
-        "extra": "forbid",
-        "validate_assignment": True,
-    }
+    model_config: ClassVar[ConfigDict] = ConfigDict(
+        arbitrary_types_allowed=True,
+        extra="ignore",
+        validate_assignment=True,
+    )
 
-    def model_dump(
+    def model_dump(  # noqa: PLR0913
         self,
         *,
-        mode: Literal["json", "python"] | str = "python",
+        mode: Literal["json", "python"] | str = "python",  # noqa: PYI051
         include: IncEx | None = None,
         exclude: IncEx | None = None,
+        context: dict[str, Any] | None = None,
         by_alias: bool = True,
         exclude_unset: bool = True,
         exclude_defaults: bool = False,
         exclude_none: bool = False,
         round_trip: bool = False,
-        warnings: bool = True,
+        warnings: bool | Literal["none", "warn", "error"] = True,
+        serialize_as_any: bool = False,
     ) -> dict[str, Any]:
-        # pylint: disable=useless-parent-delegation
         """Create a dictionary representation of the model.
 
         Overrides the standard `BaseModel.dict` method, so we can always return the
@@ -68,33 +71,35 @@ class BaseModelWithConfig(BaseModel):
             by_alias: False -> True
             exclude_unset: False -> True
         """
-
         return super().model_dump(
             mode=mode,
             include=include,
             exclude=exclude,
+            context=context,
             by_alias=by_alias,
             exclude_unset=exclude_unset,
             exclude_defaults=exclude_defaults,
             exclude_none=exclude_none,
             round_trip=round_trip,
             warnings=warnings,
+            serialize_as_any=serialize_as_any,
         )
 
-    def model_dump_json(
+    def model_dump_json(  # noqa: PLR0913
         self,
         *,
         indent: int | None = None,
         include: IncEx | None = None,
         exclude: IncEx | None = None,
+        context: dict[str, Any] | None = None,
         by_alias: bool = True,
         exclude_unset: bool = True,
         exclude_defaults: bool = False,
         exclude_none: bool = False,
         round_trip: bool = False,
-        warnings: bool = True,
+        warnings: bool | Literal["none", "warn", "error"] = True,
+        serialize_as_any: bool = False,
     ) -> str:
-        # pylint: disable=useless-parent-delegation
         """Create a JSON string representation of the model.
 
         Overrides the standard `BaseModel.json` method, so we can always return the
@@ -108,17 +113,18 @@ class BaseModelWithConfig(BaseModel):
             by_alias: False -> True
             exclude_unset: False -> True
         """
-
         return super().model_dump_json(
             indent=indent,
             include=include,
             exclude=exclude,
+            context=context,
             by_alias=by_alias,
             exclude_unset=exclude_unset,
             exclude_defaults=exclude_defaults,
             exclude_none=exclude_none,
             round_trip=round_trip,
             warnings=warnings,
+            serialize_as_any=serialize_as_any,
         )
 
 
@@ -171,7 +177,6 @@ class OAuthCredentials(BaseModelWithConfig):
         Raises:
             ValueError: if `expiry` and `expiry_epoch` aren't the same
         """
-
         # Calculate the expiry time of the access token
         try:
             # Try to decode it if it's a valid JWT (with expiry)
@@ -193,7 +198,7 @@ class OAuthCredentials(BaseModelWithConfig):
                 if abs(expiry_epoch - expiry_time.timestamp()) > 60:  # noqa: PLR2004
                     raise ValueError(
                         "`expiry` and `expires_in` are not consistent with each other:"
-                        f" expiry: {expiry_time_str}, expires_in: {expiry_epoch}"
+                        f" expiry: {expiry_time_str}, expires_in: {expiry_epoch}",
                     ) from None
 
         value["expiry_epoch"] = expiry_epoch
@@ -201,7 +206,10 @@ class OAuthCredentials(BaseModelWithConfig):
         return cls(**value)
 
     def update_access_token(
-        self, new_token: str, expires_in: int, refresh_token: str | None = None
+        self,
+        new_token: str,
+        expires_in: int,
+        refresh_token: str | None = None,
     ) -> None:
         """Update the access token and expiry time.
 
@@ -262,6 +270,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         access_token_endpoint: str | None = None,
         auth_link_base: str | None = None,
         base_url: str | None = None,
+        validate_request_success: bool = True,
     ):
         """Initialise the client.
 
@@ -291,8 +300,14 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
                 link. Defaults to None.
             base_url (str, optional): the base URL to use for API requests. Defaults to
                 None.
+            validate_request_success (bool, optional): whether to validate that the
+                request was successful. Defaults to True.
         """
-        super().__init__(log_requests=log_requests, base_url=base_url)
+        super().__init__(
+            log_requests=log_requests,
+            base_url=base_url,
+            validate_request_success=validate_request_success,
+        )
 
         self._client_id = client_id
         self._client_secret = client_secret
@@ -329,7 +344,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         """
         try:
             self._credentials = OAuthCredentials.model_validate_json(
-                self.creds_cache_path.read_text()
+                self.creds_cache_path.read_text(),
             )
         except FileNotFoundError:
             return False
@@ -342,7 +357,6 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
 
     def refresh_access_token(self) -> None:
         """Refresh access token."""
-
         if not hasattr(self, "_credentials") and not self._load_local_credentials():
             # If we don't have any credentials, we can't refresh the access token -
             # perform first time login and leave it at that
@@ -372,7 +386,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         )
 
         self.creds_cache_path.write_text(
-            self.credentials.model_dump_json(exclude_none=True)
+            self.credentials.model_dump_json(exclude_none=True),
         )
 
     def run_first_time_login(self) -> None:
@@ -386,11 +400,10 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
             ValueError: if the state token returned by the OAuth provider does not
                 match
         """
-
         if self.use_existing_credentials_only:
             raise RuntimeError(
                 "No existing credentials found, and `use_existing_credentials_only` "
-                "is set to True"
+                "is set to True",
             )
 
         LOGGER.info("Performing first time login")
@@ -402,7 +415,6 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         if self.oauth_redirect_uri_override:
             redirect_uri = self.oauth_redirect_uri_override
         else:
-            # pylint: disable=line-too-long
             redirect_uri = f"http://{self.oauth_login_redirect_host}:{self.temp_auth_server.port}/get_auth_code"
 
         auth_link_params = {
@@ -423,7 +435,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
             if self.headless_auth_link_callback is None:
                 LOGGER.warning(
                     "Headless mode is enabled, but no headless auth link callback "
-                    "has been set. The auth link will not be opened."
+                    "has been set. The auth link will not be opened.",
                 )
                 LOGGER.debug("Auth link: %s", auth_link)
             else:
@@ -433,13 +445,14 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
             open_browser(auth_link)
 
         request_args = self.temp_auth_server.wait_for_request(
-            "/get_auth_code", kill_on_request=True
+            "/get_auth_code",
+            kill_on_request=True,
         )
 
         if state_token != request_args.get("state"):
             raise ValueError(
                 "State token received in request doesn't match expected value: "
-                f"`{request_args.get('state')}` != `{state_token}`"
+                f"`{request_args.get('state')}` != `{state_token}`",
             )
 
         payload_key = (
@@ -457,12 +470,14 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
                     "client_id": self._client_id,
                     "client_secret": self._client_secret,
                     "redirect_uri": redirect_uri,
-                }
+                },
             },
             # Stops recursive call to `self.request_headers`
-            header_overrides={"Content-Type": "application/x-www-form-urlencoded"}
-            if self.__class__.__name__ in ("MonzoClient", "SpotifyClient")
-            else {},
+            header_overrides=(
+                {"Content-Type": "application/x-www-form-urlencoded"}
+                if self.__class__.__name__ in ("MonzoClient", "SpotifyClient")
+                else {}
+            ),
         )
 
         credentials = res.json()
@@ -481,7 +496,6 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
 
         Overridable in subclasses.
         """
-
         try:
             client_id = self._client_id or self._credentials.client_id
         except AttributeError:
@@ -523,7 +537,6 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         Returns:
             str: the current client ID
         """
-
         return self._client_id or self.credentials.client_id
 
     @property
@@ -533,7 +546,6 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
         Returns:
             str: the current client secret
         """
-
         return self._client_secret or self.credentials.client_secret
 
     @property
@@ -545,7 +557,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
 
         Raises:
             ValueError: if the state token returned from the request doesn't match the
-             expected value
+                expected value
         """
         if not hasattr(self, "_credentials") and not self._load_local_credentials():
             self.run_first_time_login()
@@ -555,11 +567,10 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
     @credentials.setter
     def credentials(self, value: OAuthCredentials) -> None:
         """Set the client's credentials, and write to the local cache file."""
-
         self._credentials = value
 
         self.creds_cache_path.write_text(
-            dumps(self._credentials.model_dump(exclude_none=True))
+            dumps(self._credentials.model_dump(exclude_none=True)),
         )
 
     @property
@@ -578,7 +589,7 @@ class OAuthClient(JsonApiClient[GetJsonResponse]):
 
         if not self._creds_rel_file_path:
             raise ValueError(
-                "Unable to get client ID to generate path for credentials cache file."
+                "Unable to get client ID to generate path for credentials cache file.",
             )
 
         return force_mkdir(
