@@ -1,20 +1,34 @@
 """Custom client for interacting with TrueLayer's API."""
+
 from __future__ import annotations
 
-from collections.abc import Callable, Iterable
-from datetime import date, datetime, timedelta
+from datetime import UTC, date, datetime, timedelta
 from enum import Enum, StrEnum, auto
 from logging import DEBUG, getLogger
 from pathlib import Path
-from typing import Any, ClassVar, Literal, Self, TypeAlias, TypeVar
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    ClassVar,
+    Literal,
+    NotRequired,
+    Self,
+    TypeAlias,
+    TypeVar,
+    overload,
+)
 
 from pydantic import Field, field_validator
 from requests import HTTPError
-from typing_extensions import NotRequired, TypedDict
+from typing_extensions import TypedDict
 
-from wg_utilities.clients.json_api_client import StrBytIntFlt
 from wg_utilities.clients.oauth_client import BaseModelWithConfig, OAuthClient
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable
+
+    from wg_utilities.clients.json_api_client import StrBytIntFlt
+
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
 
@@ -75,7 +89,7 @@ class TransactionCategory(Enum):
     """Enum for TrueLayer transaction types.
 
     __init__ method is overridden to allow setting a description as well as the main
-     value.
+    value.
     """
 
     ATM = (
@@ -171,7 +185,7 @@ class BalanceVariables(BaseModelWithConfig):
 class _TrueLayerEntityProvider(BaseModelWithConfig):
     display_name: str
     logo_uri: str
-    id: str = Field(alias="provider_id")  # noqa: A003
+    id: str = Field(alias="provider_id")
 
 
 TrueLayerEntityJson: TypeAlias = AccountJson | CardJson
@@ -182,7 +196,7 @@ class TrueLayerEntity(BaseModelWithConfig):
 
     BALANCE_FIELDS: ClassVar[Iterable[str]] = ()
 
-    id: str = Field(alias="account_id")  # noqa: A003
+    id: str = Field(alias="account_id")
     currency: str
     display_name: str
     provider: _TrueLayerEntityProvider
@@ -190,24 +204,20 @@ class TrueLayerEntity(BaseModelWithConfig):
 
     _available_balance: float
     _current_balance: float
-    _overdraft: float
-    _credit_limit: float
-    _last_statement_balance: float
-    _last_statement_date: date
-    _payment_due: float
-    _payment_due_date: date
 
     truelayer_client: TrueLayerClient = Field(exclude=True)
     balance_update_threshold: timedelta = Field(timedelta(minutes=15), exclude=True)
-    last_balance_update: datetime = Field(datetime(1970, 1, 1), exclude=True)
+    last_balance_update: datetime = Field(datetime(1970, 1, 1, tzinfo=UTC), exclude=True)
     _balance_variables: BalanceVariables
 
     @classmethod
     def from_json_response(
-        cls, value: TrueLayerEntityJson, *, truelayer_client: TrueLayerClient
+        cls,
+        value: TrueLayerEntityJson,
+        *,
+        truelayer_client: TrueLayerClient,
     ) -> Self:
         """Create an account from a JSON response."""
-
         value_data: dict[str, Any] = {
             "truelayer_client": truelayer_client,
             **value,
@@ -233,15 +243,17 @@ class TrueLayerEntity(BaseModelWithConfig):
         Returns:
             list[Transaction]: one instance per tx, including all metadata etc.
         """
-
         if from_datetime or to_datetime:
-            from_datetime = from_datetime or datetime.utcnow() - timedelta(days=90)
-            to_datetime = to_datetime or datetime.utcnow()
+            from_datetime = from_datetime or datetime.now(UTC) - timedelta(days=90)
+            to_datetime = to_datetime or datetime.now(UTC)
 
-            params: dict[
-                StrBytIntFlt,
-                StrBytIntFlt | Iterable[StrBytIntFlt] | None,
-            ] | None = {
+            params: (
+                dict[
+                    StrBytIntFlt,
+                    StrBytIntFlt | Iterable[StrBytIntFlt] | None,
+                ]
+                | None
+            ) = {
                 "from": from_datetime.isoformat(),
                 "to": to_datetime.isoformat(),
             }
@@ -264,30 +276,26 @@ class TrueLayerEntity(BaseModelWithConfig):
         was updated more than `self.balance_update_threshold`minutes ago), but
         can also be called manually.
         """
-
         results = self.truelayer_client.get_json_response(
-            f"/data/v1/{self.__class__.__name__.lower()}s/{self.id}/balance"
+            f"/data/v1/{self.__class__.__name__.lower()}s/{self.id}/balance",
         ).get("results", [])
 
         if len(results) != 1:
             raise ValueError(
-                "Unexpected number of results when getting balance info:"
-                f" {len(results)}",
+                f"Unexpected number of results when getting balance info: {len(results)}",
             )
 
         balance_result = results[0]
 
         for k, v in balance_result.items():
-            if k in (
-                "available",
-                "current",
-            ):
+            if k in {"available", "current"}:
                 attr_name = f"_{k}_balance"
             elif k.endswith("_date"):
                 attr_name = f"_{k}"
                 if isinstance(v, str):
-                    v = datetime.strptime(  # noqa: PLW2901
-                        v, "%Y-%m-%dT%H:%M:%SZ"
+                    v = datetime.strptime(  # noqa: DTZ007, PLW2901
+                        v,
+                        "%Y-%m-%dT%H:%M:%SZ",
                     ).date()
             else:
                 attr_name = f"_{k}"
@@ -300,7 +308,34 @@ class TrueLayerEntity(BaseModelWithConfig):
 
             setattr(self, attr_name, v)
 
-        self.last_balance_update = datetime.utcnow()
+        self.last_balance_update = datetime.now(UTC)
+
+    @overload
+    def _get_balance_property(
+        self,
+        prop_name: Literal["current_balance"],
+    ) -> float: ...
+
+    @overload
+    def _get_balance_property(
+        self,
+        prop_name: Literal[
+            "available_balance",
+            "overdraft",
+            "credit_limit",
+            "last_statement_balance",
+            "payment_due",
+        ],
+    ) -> float | None: ...
+
+    @overload
+    def _get_balance_property(
+        self,
+        prop_name: Literal[
+            "last_statement_date",
+            "payment_due_date",
+        ],
+    ) -> date | None: ...
 
     def _get_balance_property(
         self,
@@ -314,7 +349,7 @@ class TrueLayerEntity(BaseModelWithConfig):
             "payment_due",
             "payment_due_date",
         ],
-    ) -> str | float | int | None:
+    ) -> float | date | None:
         """Get a value for a balance-specific property.
 
         Updates the values if necessary (i.e. if they don't already exist). This also
@@ -327,7 +362,6 @@ class TrueLayerEntity(BaseModelWithConfig):
         Returns:
             str: the value of the balance property
         """
-
         if prop_name not in self.BALANCE_FIELDS:
             return None
 
@@ -335,14 +369,14 @@ class TrueLayerEntity(BaseModelWithConfig):
             not hasattr(self, f"_{prop_name}")
             or getattr(self, f"_{prop_name}") is None
             or self.last_balance_update
-            <= (datetime.utcnow() - self.balance_update_threshold)
+            <= (datetime.now(UTC) - self.balance_update_threshold)
         ):
             self.update_balance_values()
 
         return getattr(self, f"_{prop_name}", None)
 
     @property
-    def available_balance(self) -> str | float | int | None:
+    def available_balance(self) -> float | None:
         """Available balance for the entity.
 
         Returns:
@@ -351,69 +385,20 @@ class TrueLayerEntity(BaseModelWithConfig):
         return self._get_balance_property("available_balance")
 
     @property
-    def current_balance(self) -> str | float | int | None:
+    def balance(self) -> float:
+        """Get the available balance, or current if available is not available."""
+        return self.available_balance or self.current_balance
+
+    @property
+    def current_balance(self) -> float:
         """Current balance of the account.
 
         Returns:
             float: the total amount of money in the account, including pending
-             transactions
+                transactions
         """
         return self._get_balance_property("current_balance")
 
-    @property
-    def overdraft(self) -> str | float | int | None:
-        """Overdraft limit for the account.
-
-        Returns:
-            float: the overdraft limit of the account
-        """
-        return self._get_balance_property("overdraft")
-
-    @property
-    def credit_limit(self) -> str | float | int | None:
-        """Credit limit of the account.
-
-        Returns:
-            float: the credit limit available to the customer
-        """
-        return self._get_balance_property("credit_limit")
-
-    @property
-    def last_statement_balance(self) -> str | float | int | None:
-        """Balance of the account at the last statement date.
-
-        Returns:
-            float: the balance on the last statement
-        """
-        return self._get_balance_property("last_statement_balance")
-
-    @property
-    def last_statement_date(self) -> str | float | int | None:
-        """Date of the last statement.
-
-        Returns:
-            date: the date the last statement was issued on
-        """
-        return self._get_balance_property("last_statement_date")
-
-    @property
-    def payment_due(self) -> str | float | int | None:
-        """Amount due on the next statement.
-
-        Returns:
-            float: the amount of any due payment
-        """
-        return self._get_balance_property("payment_due")
-
-    @property
-    def payment_due_date(self) -> str | float | int | None:
-        """Date of the next statement.
-
-        Returns:
-            date: the date on which the next payment is due
-        """
-        return self._get_balance_property("payment_due_date")
-
     def __str__(self) -> str:
         """Return a string representation of the entity."""
         return f"{self.display_name} | {self.provider.display_name}"
@@ -425,7 +410,7 @@ class Transaction(BaseModelWithConfig):
     amount: float
     currency: str
     description: str
-    id: str = Field(alias="transaction_id")  # noqa: A003
+    id: str = Field(alias="transaction_id")
     merchant_name: str | None = None
     meta: dict[str, str]
     normalised_provider_transaction_id: str | None = None
@@ -468,6 +453,8 @@ class Account(TrueLayerEntity):
     account_number: _AccountNumber
     account_type: AccountType
 
+    _overdraft: float
+
     @field_validator("account_type", mode="before")
     @classmethod
     def validate_account_type(cls, value: str) -> AccountType:
@@ -480,6 +467,15 @@ class Account(TrueLayerEntity):
 
         return AccountType[value.upper()]
 
+    @property
+    def overdraft(self) -> float | None:
+        """Overdraft limit for the account.
+
+        Returns:
+            float: the overdraft limit of the account
+        """
+        return self._get_balance_property("overdraft")
+
 
 class Card(TrueLayerEntity):
     """Class for managing individual cards."""
@@ -501,6 +497,57 @@ class Card(TrueLayerEntity):
     valid_from: date | None = None
     valid_to: date | None = None
 
+    _credit_limit: float
+    _last_statement_balance: float
+    _last_statement_date: date
+    _payment_due: float
+    _payment_due_date: date
+
+    @property
+    def credit_limit(self) -> float | None:
+        """Credit limit of the account.
+
+        Returns:
+            float: the credit limit available to the customer
+        """
+        return self._get_balance_property("credit_limit")
+
+    @property
+    def last_statement_balance(self) -> float | None:
+        """Balance of the account at the last statement date.
+
+        Returns:
+            float: the balance on the last statement
+        """
+        return self._get_balance_property("last_statement_balance")
+
+    @property
+    def last_statement_date(self) -> date | None:
+        """Date of the last statement.
+
+        Returns:
+            date: the date the last statement was issued on
+        """
+        return self._get_balance_property("last_statement_date")
+
+    @property
+    def payment_due(self) -> float | None:
+        """Amount due on the next statement.
+
+        Returns:
+            float: the amount of any due payment
+        """
+        return self._get_balance_property("payment_due")
+
+    @property
+    def payment_due_date(self) -> date | None:
+        """Date of the next statement.
+
+        Returns:
+            date: the date on which the next payment is due
+        """
+        return self._get_balance_property("payment_due_date")
+
 
 AccountOrCard = TypeVar("AccountOrCard", Account, Card)
 
@@ -536,6 +583,7 @@ class TrueLayerClient(OAuthClient[dict[Literal["results"], list[TrueLayerEntityJ
         oauth_redirect_uri_override: str | None = None,
         headless_auth_link_callback: Callable[[str], None] | None = None,
         use_existing_credentials_only: bool = False,
+        validate_request_success: bool = True,
         bank: Bank,
     ):
         super().__init__(
@@ -551,6 +599,7 @@ class TrueLayerClient(OAuthClient[dict[Literal["results"], list[TrueLayerEntityJ
             oauth_login_redirect_host=oauth_login_redirect_host,
             oauth_redirect_uri_override=oauth_redirect_uri_override,
             headless_auth_link_callback=headless_auth_link_callback,
+            validate_request_success=validate_request_success,
             use_existing_credentials_only=use_existing_credentials_only,
         )
 
@@ -572,12 +621,12 @@ class TrueLayerClient(OAuthClient[dict[Literal["results"], list[TrueLayerEntityJ
 
         Raises:
             HTTPError: if a HTTPError is raised by the request, and it's not because
-             the ID wasn't found
+                the ID wasn't found
             ValueError: if >1 result is returned from the TrueLayer API
         """
         try:
             results = self.get_json_response(
-                f"/data/v1/{entity_class.__name__.lower()}s/{entity_id}"
+                f"/data/v1/{entity_class.__name__.lower()}s/{entity_id}",
             ).get("results", [])
         except HTTPError as exc:
             if (
@@ -603,7 +652,7 @@ class TrueLayerClient(OAuthClient[dict[Literal["results"], list[TrueLayerEntityJ
 
         Returns:
             list[Union([Account, Card])]: a list of Account/Card instances with
-             associated info
+                associated info
 
         Raises:
             HTTPError: if a HTTPError is raised by the `_get` method, but it's not a 501
@@ -679,7 +728,6 @@ class TrueLayerClient(OAuthClient[dict[Literal["results"], list[TrueLayerEntityJ
         TrueLayer shares the same Client ID for all banks, so this overrides the default
         to separate credentials by bank.
         """
-
         try:
             client_id = self._client_id or self._credentials.client_id
         except AttributeError:
