@@ -1,4 +1,5 @@
 """Drivers obtained from https://github.com/waveshare/e-Paper/."""
+
 from __future__ import annotations
 
 from logging import DEBUG, Formatter, StreamHandler, getLogger
@@ -8,7 +9,8 @@ from .epd7in5_v2 import EPD_HEIGHT, EPD_WIDTH
 from .epdconfig import TEST_MODE, implementation
 
 _FORMATTER = Formatter(
-    "%(asctime)s\t%(name)s\t[%(levelname)s]\t%(message)s", "%Y-%m-%d %H:%M:%S"
+    "%(asctime)s\t%(name)s\t[%(levelname)s]\t%(message)s",
+    "%Y-%m-%d %H:%M:%S",
 )
 
 _SH = StreamHandler(stdout)
@@ -35,4 +37,4 @@ else:
         if not method.startswith("_"):
             setattr(EPD, method, lambda *_, **__: None)
 
-__all__ = ["EPD", "EPD_HEIGHT", "EPD_WIDTH", "implementation", "FRAME_DELAY"]
+__all__ = ["EPD", "EPD_HEIGHT", "EPD_WIDTH", "FRAME_DELAY", "implementation"]
