@@ -1,10 +1,10 @@
 """Classes etc. for subscribing to YAS-209 updates."""
+
 from __future__ import annotations
 
 from asyncio import new_event_loop, run
 from asyncio import sleep as async_sleep
-from collections.abc import Callable, Coroutine, Mapping, MutableMapping, Sequence
-from datetime import datetime, timedelta
+from datetime import UTC, datetime, timedelta
 from enum import Enum
 from functools import wraps
 from logging import DEBUG, getLogger
@@ -12,10 +12,9 @@ from re import compile as re_compile
 from textwrap import dedent
 from threading import Thread
 from time import sleep, strptime
-from typing import Any, ClassVar, Literal, TypeVar
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeVar
 
 from async_upnp_client.aiohttp import AiohttpNotifyServer, AiohttpRequester
-from async_upnp_client.client import UpnpDevice, UpnpService, UpnpStateVariable
 from async_upnp_client.client_factory import UpnpFactory
 from async_upnp_client.exceptions import UpnpCommunicationError
 from async_upnp_client.utils import get_local_ip
@@ -24,11 +23,14 @@ from typing_extensions import TypedDict
 from xmltodict import parse as parse_xml
 
 from wg_utilities.functions import traverse_dict
-from wg_utilities.loggers import add_stream_handler
+
+if TYPE_CHECKING:
+    from collections.abc import Callable, Coroutine, Mapping, MutableMapping, Sequence
+
+    from async_upnp_client.client import UpnpDevice, UpnpService, UpnpStateVariable
 
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
-add_stream_handler(LOGGER)
 
 
 class StateVariable(BaseModel, extra="allow"):
@@ -49,7 +51,7 @@ class CurrentTrackMetaDataItemRes(BaseModel, extra="allow"):
 class TrackMetaDataItem(BaseModel, extra="allow"):
     """BaseModel for part of the DLNA payload."""
 
-    id: str  # noqa: A003
+    id: str
     song_subid: str | None = Field(None, alias="song:subid")
     song_description: str | None = Field(None, alias="song:description")
     song_skiplimit: str | None = Field(None, alias="song:skiplimit")
@@ -233,9 +235,7 @@ class CurrentTrack:
         self.media_title = media_title
 
     @classmethod
-    def _create_from_metadata_item(
-        cls, metadata_item: TrackMetaDataItem
-    ) -> CurrentTrack:
+    def _create_from_metadata_item(cls, metadata_item: TrackMetaDataItem) -> CurrentTrack:
         """Create a CurrentTrack instance from a response metadata item.
 
         Args:
@@ -253,9 +253,11 @@ class CurrentTrack:
         )
 
         return CurrentTrack(
-            album_art_uri=metadata_item.upnp_albumArtURI
-            if metadata_item.upnp_albumArtURI != "un_known"
-            else None,
+            album_art_uri=(
+                metadata_item.upnp_albumArtURI
+                if metadata_item.upnp_albumArtURI != "un_known"
+                else None
+            ),
             media_album_name=metadata_item.upnp_album,
             media_artist=metadata_item.dc_creator,
             media_duration=duration_delta.total_seconds(),
@@ -285,7 +287,7 @@ class CurrentTrack:
             CurrentTrack: a CurrentTrack instance with relevant info
         """
         return cls._create_from_metadata_item(
-            last_change.Event.InstanceID.CurrentTrackMetaData.item
+            last_change.Event.InstanceID.CurrentTrackMetaData.item,
         )
 
     @classmethod
@@ -338,7 +340,6 @@ class CurrentTrack:
 
     def __str__(self) -> str:
         """Return a string representation of the current track."""
-
         if self.media_title is None and self.media_artist is None:
             return self.NULL_TRACK_STR
 
@@ -476,7 +477,11 @@ class Yas209Service(Enum):
     )
 
     def __init__(
-        self, value: str, service_id: str, service_name: str, actions: tuple[str]
+        self,
+        value: str,
+        service_id: str,
+        service_name: str,
+        actions: tuple[str],
     ):
         self._value_ = value
         self.service_id = service_id
@@ -485,7 +490,7 @@ class Yas209Service(Enum):
 
 
 def _needs_device(
-    func: Callable[[YamahaYas209], Coroutine[Any, Any, Mapping[str, Any] | None]]
+    func: Callable[[YamahaYas209], Coroutine[Any, Any, Mapping[str, Any] | None]],
 ) -> Callable[[YamahaYas209], Any]:
     """Use as a decorator to ensure the device is available.
 
@@ -515,7 +520,7 @@ def _needs_device(
 
             async def _create() -> None:
                 yas_209.device = await factory.async_create_device(
-                    yas_209.description_url
+                    yas_209.description_url,
                 )
 
             run(_create())
@@ -621,7 +626,7 @@ class YamahaYas209:
         if self._listen_ip is not None and self._listen_port is None:
             raise ValueError(
                 "Argument `listen_port` cannot be None when `listen_ip` is not None:"
-                f" {self._listen_ip!r}"
+                f" {self._listen_ip!r}",
             )
 
         if start_listener:
@@ -646,7 +651,7 @@ class YamahaYas209:
             nonlocal worker_exception
             try:
                 new_event_loop().run_until_complete(self._subscribe())
-            except Exception as exc:  # pylint: disable=broad-except
+            except Exception as exc:
                 worker_exception = exc
 
         listener_thread = Thread(target=_worker)
@@ -656,7 +661,7 @@ class YamahaYas209:
             sleep(0.01)
 
         if isinstance(worker_exception, BaseException):
-            raise worker_exception  # pylint: disable=raising-bad-type
+            raise worker_exception
 
         if self._logging:
             LOGGER.debug(
@@ -665,7 +670,9 @@ class YamahaYas209:
             )
 
     def on_event_wrapper(
-        self, service: UpnpService, service_variables: Sequence[UpnpStateVariable[str]]
+        self,
+        service: UpnpService,
+        service_variables: Sequence[UpnpStateVariable[str]],
     ) -> None:
         """Wrap the `on_event` callback to process the XML payload(s) first.
 
@@ -673,20 +680,17 @@ class YamahaYas209:
             service (UpnpService): the service which has sent an update
             service_variables (list): a list of state variables that have updated
         """
-
-        xml_payloads: dict[str, object] = {
-            sv.name: sv.value for sv in service_variables
-        }
+        xml_payloads: dict[str, object] = {sv.name: sv.value for sv in service_variables}
 
         # Convert any nested XML into JSON
         self._parse_xml_dict(xml_payloads)
 
         last_change = self.LAST_CHANGE_PAYLOAD_PARSERS[service.service_id](
-            xml_payloads.pop("LastChange")  # type: ignore[arg-type]
+            xml_payloads.pop("LastChange"),  # type: ignore[arg-type]
         )
 
         event_payload: YamahaYas209.EventPayloadInfo = {
-            "timestamp": datetime.utcnow(),
+            "timestamp": datetime.now(UTC),
             "service_id": service.service_id,
             "service_type": service.service_type,
             "last_change": last_change,
@@ -706,15 +710,15 @@ class YamahaYas209:
         elif service.service_id == "urn:upnp-org:serviceId:RenderingControl":
             # The DLNA payload has volume as a string value between 0 and 100
             self.set_volume_level(
-                float(last_change.Event.InstanceID.Volume.val) / 100, local_only=True
+                float(last_change.Event.InstanceID.Volume.val) / 100,
+                local_only=True,
             )
 
         if self.on_event is not None:
             self.on_event(event_payload)
 
     @_needs_device
-    async def _subscribe(self) -> None:  # noqa: PLR0912
-        # pylint: disable=too-many-branches
+    async def _subscribe(self) -> None:  # noqa: C901, PLR0912
         """Subscribe to service(s) and output updates."""
         # start notify server/event handler
         local_ip = get_local_ip(self.device.device_url)
@@ -726,7 +730,9 @@ class YamahaYas209:
             else f"http://{self._listen_ip or local_ip}:{self._listen_port}/notify"
         )
         server = AiohttpNotifyServer(
-            self.device.requester, source=source, callback_url=callback_url
+            self.device.requester,
+            source=source,
+            callback_url=callback_url,
         )
         await server.async_start_server()
 
@@ -741,7 +747,7 @@ class YamahaYas209:
             Callback URL:       %s
             Server Listen IP:   %s
             Server Listen Port: %s
-            """
+            """,
                 ),
                 self._listen_ip,
                 str(self._listen_port),
@@ -794,8 +800,7 @@ class YamahaYas209:
                 try:
                     if self._logging:
                         LOGGER.debug(
-                            "Attempting to create originally failed subscription for"
-                            " %s",
+                            "Attempting to create originally failed subscription for %s",
                             service.service_id,
                         )
                     await server.event_handler.async_subscribe(service)
@@ -803,8 +808,7 @@ class YamahaYas209:
                     services_to_remove.append(service)
                 except UpnpCommunicationError as exc:
                     log_message = (
-                        f"Still unable to subscribe to {service.service_id}:"
-                        f" {exc!r}"
+                        f"Still unable to subscribe to {service.service_id}: {exc!r}"
                     )
 
                     if self._logging:
@@ -835,7 +839,7 @@ class YamahaYas209:
         if action not in service.actions:
             raise ValueError(
                 f"Unexpected action {action!r} for service {service.value!r}. "
-                f"""Must be one of '{"', '".join(service.actions)}'"""
+                f"""Must be one of '{"', '".join(service.actions)}'""",
             )
 
         @_needs_device
@@ -863,14 +867,15 @@ class YamahaYas209:
         Args:
             xml_dict (dict): the dictionary to parse
         """
-
         pattern = re_compile(r"&(?!(amp|apos|lt|gt|quot);)")
 
         traverse_dict(
             xml_dict,
             target_type=str,
             target_processor_func=lambda val, **_: parse_xml(  # type: ignore[arg-type]
-                pattern.sub("&amp;", val), attr_prefix="", cdata_key="text"
+                pattern.sub("&amp;", val),
+                attr_prefix="",
+                cdata_key="text",
             ),
             single_keys_to_remove=["val", "DIDL-Lite"],
         )
@@ -915,7 +920,7 @@ class YamahaYas209:
         Args:
             value (Yas209State): the new state of the YAS-209
             local_only (bool): only change the local value of the state (i.e. don't
-             update the soundbar)
+                update the soundbar)
 
         Raises:
             TypeError: if the value is not a valid state
@@ -944,12 +949,11 @@ class YamahaYas209:
         Args:
             value (float): the new volume level, as a float between 0 and 1
             local_only (bool): only change the local value of the volume level (i.e.
-             don't update the soundbar)
+                don't update the soundbar)
 
         Raises:
             ValueError: if the value is not between 0 and 1
         """
-
         if not 0 <= value <= 1:
             raise ValueError("Volume level must be between 0 and 1")
 
@@ -1018,7 +1022,7 @@ class YamahaYas209:
         if not hasattr(self, "_current_track"):
             media_info = self.get_media_info()
             self._current_track = CurrentTrack.from_get_media_info(
-                GetMediaInfoResponse.model_validate(media_info)
+                GetMediaInfoResponse.model_validate(media_info),
             )
 
         return self._current_track
@@ -1033,7 +1037,6 @@ class YamahaYas209:
         Raises:
             TypeError: if the value is not a CurrentTrack instance
         """
-
         if not isinstance(value, CurrentTrack):
             raise TypeError("Expected a CurrentTrack instance.")
 
@@ -1084,7 +1087,6 @@ class YamahaYas209:
         Returns:
             dict: the response in JSON form
         """
-
         media_info = (
             self._call_service_action(Yas209Service.AVT, "GetMediaInfo", InstanceID=0)
             or {}
