@@ -1,12 +1,11 @@
 """Helper functions for all things date and time related."""
+
 from __future__ import annotations
 
-from datetime import datetime
+from datetime import UTC, datetime
 from enum import Enum
 from typing import overload
 
-from pytz import utc
-
 
 class DatetimeFixedUnit(Enum):
     """Enum for fixed units of time (i.e. not a month or a year).
@@ -28,13 +27,11 @@ DTU = DatetimeFixedUnit
 
 
 @overload
-def utcnow() -> datetime:
-    ...
+def utcnow() -> datetime: ...
 
 
 @overload
-def utcnow(unit: DatetimeFixedUnit) -> int:
-    ...
+def utcnow(unit: DatetimeFixedUnit) -> int: ...
 
 
 def utcnow(unit: DatetimeFixedUnit | None = None) -> datetime | int:
@@ -49,15 +46,14 @@ def utcnow(unit: DatetimeFixedUnit | None = None) -> datetime | int:
     Returns:
         Union([datetime, int]): the current UTC datetime in the chosen unit
     """
-
     if not unit:
-        return datetime.utcnow().replace(tzinfo=utc)
+        return datetime.now(UTC)
 
-    return int(datetime.utcnow().replace(tzinfo=utc).timestamp() / unit.value)
+    return int(datetime.now(UTC).timestamp() / unit.value)
 
 
 __all__ = [
-    "DatetimeFixedUnit",
     "DTU",
+    "DatetimeFixedUnit",
     "utcnow",
 ]
