@@ -1,18 +1,27 @@
-"""Useful functions for working with JSON/dictionaries."""
+"""Useful functions for working with JSON/dictionaries."""  # noqa: A005
+
 from __future__ import annotations
 
-from collections.abc import Callable, Sequence
+from collections.abc import MutableMapping, Sequence
 from logging import DEBUG, getLogger
-from typing import Any, Protocol, Union
+from typing import Any, Protocol, TypeVar, Union, cast
 
 LOGGER = getLogger(__name__)
 LOGGER.setLevel(DEBUG)
 
-
 JSONVal = Union[
-    None, object, bool, str, float, int, list["JSONVal"], "JSONObj", dict[str, object]
+    None,
+    object,
+    bool,
+    str,
+    float,
+    int,
+    list["JSONVal"],
+    "JSONObj",
+    dict[str, object],
 ]
-JSONObj = dict[str, JSONVal]
+JSONObj = MutableMapping[str, JSONVal]
+JSONArr = Sequence[JSONVal]
 
 
 def set_nested_value(
@@ -30,7 +39,6 @@ def set_nested_value(
         target_value (Any): the value to set at the given location/path
         final_key (str): the final key, the value of which we're actually setting
     """
-
     final_key = final_key or keys.pop()
 
     if len(keys) > 0:
@@ -44,24 +52,29 @@ def set_nested_value(
         json_obj[final_key] = target_value
 
 
-class TargetProcessorFunc(Protocol):
+V_contra = TypeVar("V_contra", contravariant=True, bound=JSONVal)
+V = TypeVar("V", bound=JSONVal)
+
+
+class TargetProcessorFunc(Protocol[V_contra]):
     """Typing protocol for the user-defined function passed into the below functions."""
 
     def __call__(
         self,
-        value: JSONVal,
+        value: V_contra,
         *,
         dict_key: str | None = None,
         list_index: int | None = None,
     ) -> JSONVal:
-        """The function to be called on each value in the JSON object."""  # noqa: D401
+        """The function to be called on each value in the JSON object."""
 
 
 def process_list(
     lst: list[JSONVal],
+    /,
     *,
-    target_type: type[object] | tuple[type[object], ...],
-    target_processor_func: TargetProcessorFunc,
+    target_type: type[V] | tuple[type[V], ...],
+    target_processor_func: TargetProcessorFunc[V],
     pass_on_fail: bool = True,
     log_op_func_failures: bool = False,
     single_keys_to_remove: Sequence[str] | None = None,
@@ -79,12 +92,10 @@ def process_list(
     Args:
         lst (list): the list to iterate through
         target_type (type): the target type to apply functions to
-        target_processor_func (Callable): a function to apply to instances of
-         `target_type`
+        target_processor_func (Callable): a function to apply to instances of `target_type`
         pass_on_fail (bool): ignore failure in either op function
         log_op_func_failures (bool): log any failures in either op function
-        single_keys_to_remove (list): a list of keys that can be "expanded" up to the
-         parent key
+        single_keys_to_remove (list): a list of keys that can be "expanded" up to the parent key
 
     Raises:
         Exception: if the `target_processor_func` fails and `pass_on_fail` is False
@@ -92,52 +103,47 @@ def process_list(
     for i, elem in enumerate(lst):
         if isinstance(elem, target_type):
             try:
-                lst[i] = target_processor_func(elem, list_index=i)
-            except Exception as exc:  # pylint: disable=broad-except
+                lst[i] = target_processor_func(cast(V, elem), list_index=i)
+            except Exception:
                 if log_op_func_failures:
-                    LOGGER.error("Unable to process item at index %i: %s", i, repr(exc))
+                    LOGGER.exception("Unable to process item at index %i", i)
+
                 if not pass_on_fail:
                     raise
-        elif isinstance(elem, dict):
-            traverse_dict(
-                elem,
+
+        # If the new(?) value is a dict/list, then it needs to be processed
+        # before continuing to the next elem in this list
+        if isinstance(lst[i], dict | list):
+            process_json_object(
+                lst[i],  # type: ignore[arg-type]
                 target_type=target_type,
                 target_processor_func=target_processor_func,
                 pass_on_fail=pass_on_fail,
                 log_op_func_failures=log_op_func_failures,
                 single_keys_to_remove=single_keys_to_remove,
             )
-        elif isinstance(elem, list):
-            process_list(
-                elem,
-                target_type=target_type,
-                target_processor_func=target_processor_func,
-                pass_on_fail=pass_on_fail,
-                log_op_func_failures=log_op_func_failures,
-            )
 
 
-def traverse_dict(
-    payload_json: JSONObj,
+def traverse_dict(  # noqa: C901, PLR0912
+    obj: JSONObj,
+    /,
     *,
-    target_type: type[object] | tuple[type[object], ...] | type[Callable[..., Any]],
-    target_processor_func: TargetProcessorFunc,
+    target_type: type[V] | tuple[type[V], ...],
+    target_processor_func: TargetProcessorFunc[V],
     pass_on_fail: bool = True,
     log_op_func_failures: bool = False,
     single_keys_to_remove: Sequence[str] | None = None,
 ) -> None:
-    # pylint: disable=too-many-branches
-    """Traverse dict, applying`dict_op_func` to any values of type `target_type`.
+    """Traverse dict, applying`target_processor_func` to any values of type `target_type`.
 
     Args:
-        payload_json (dict): the JSON object to traverse
+        obj (dict): the JSON object to traverse
         target_type (type): the target type to apply functions to
-        target_processor_func (Callable): a function to apply to instances of
-         `target_type`
+        target_processor_func (Callable): a function to apply to instances of `target_type`
         pass_on_fail (bool): ignore failure in either op function
         log_op_func_failures (bool): log any failures in either op function
-        single_keys_to_remove (list): a list of keys that can be "expanded" up to the
-         parent key from a dict of length one, e.g.:
+        single_keys_to_remove (list): a list of keys that can be "expanded" up to the parent key from a dict of
+            length one, e.g.:
             ... {
             ...     "parent_1": "something",
             ...     "parent_2": {
@@ -153,59 +159,68 @@ def traverse_dict(
     Raises:
         Exception: if the `target_processor_func` fails and `pass_on_fail` is False
     """
-    for k, v in payload_json.items():
+    for k, v in obj.items():
         if isinstance(v, target_type):
             try:
-                payload_json.update({k: target_processor_func(v, dict_key=k)})
-                if isinstance(payload_json.get(k), dict):
+                obj.update({k: target_processor_func(cast(V, v), dict_key=k)})
+                if isinstance(obj[k], dict):
                     traverse_dict(
-                        payload_json,
+                        # If a dict has been created from a non-dict type (e.g. `loads("{...}")`,
+                        # then we need to traverse the current object again, as the new dict may
+                        # contain more instances of `target_type`. Otherwise, traverse
+                        # the dict (that already existed).
+                        obj if target_type is not dict else cast(JSONObj, obj[k]),
                         target_type=target_type,
                         target_processor_func=target_processor_func,
                         pass_on_fail=pass_on_fail,
                         log_op_func_failures=log_op_func_failures,
                         single_keys_to_remove=single_keys_to_remove,
                     )
-            except Exception as exc:  # pylint: disable=broad-except
+            except Exception:
                 if log_op_func_failures:
-                    LOGGER.error("Unable to process item with key %s: %s", k, repr(exc))
+                    LOGGER.exception("Unable to process item with key %s", k)
                 if not pass_on_fail:
                     raise
-        elif isinstance(v, dict):
+
+            continue
+
+        if isinstance(v, dict):
             matched_single_key = False
-            if len(v) == 1 and single_keys_to_remove is not None:
-                if (only_key := next(iter(v.keys()))) in single_keys_to_remove:
-                    matched_single_key = True
-                    if isinstance(value := v.get(only_key), target_type):
-                        try:
-                            value = target_processor_func(value, dict_key=only_key)
-                        except Exception as exc:  # pylint: disable=broad-except
-                            if log_op_func_failures:
-                                LOGGER.error(
-                                    "Unable to process item with key %s: %s",
-                                    k,
-                                    repr(exc),
-                                )
-                            if not pass_on_fail:
-                                raise
+            if (
+                len(v) == 1
+                and single_keys_to_remove is not None
+                and (only_key := next(iter(v.keys()))) in single_keys_to_remove
+            ):
+                matched_single_key = True
+                if isinstance(value := v.get(only_key), target_type):
+                    try:
+                        value = target_processor_func(cast(V, value), dict_key=only_key)
+                    except Exception:
+                        if log_op_func_failures:
+                            LOGGER.exception(
+                                "Unable to process item with key %s",
+                                k,
+                            )
+                        if not pass_on_fail:
+                            raise
 
-                    if isinstance(value, dict):
-                        # Wrap the value, so that if the top level key is one
-                        # of `single_keys_to_remove` then it's processed
-                        # correctly
-                        tmp_wrapper: JSONObj = {"-": value}
-                        traverse_dict(
-                            tmp_wrapper,
-                            target_type=target_type,
-                            target_processor_func=target_processor_func,
-                            pass_on_fail=pass_on_fail,
-                            log_op_func_failures=log_op_func_failures,
-                            single_keys_to_remove=single_keys_to_remove,
-                        )
+                if isinstance(value, dict):
+                    # Wrap the value, so that if the top level key is one
+                    # of `single_keys_to_remove` then it's processed
+                    # correctly
+                    tmp_wrapper: JSONObj = {"-": value}
+                    traverse_dict(
+                        tmp_wrapper,
+                        target_type=target_type,
+                        target_processor_func=target_processor_func,
+                        pass_on_fail=pass_on_fail,
+                        log_op_func_failures=log_op_func_failures,
+                        single_keys_to_remove=single_keys_to_remove,
+                    )
 
-                        value = tmp_wrapper["-"]
+                    value = tmp_wrapper["-"]
 
-                    payload_json[k] = value
+                obj[k] = value
 
             if not matched_single_key:
                 traverse_dict(
@@ -216,7 +231,10 @@ def traverse_dict(
                     log_op_func_failures=log_op_func_failures,
                     single_keys_to_remove=single_keys_to_remove,
                 )
-        elif isinstance(v, list):
+
+            continue
+
+        if isinstance(v, list):
             process_list(
                 v,
                 target_type=target_type,
@@ -225,3 +243,50 @@ def traverse_dict(
                 log_op_func_failures=log_op_func_failures,
                 single_keys_to_remove=single_keys_to_remove,
             )
+
+
+class InvalidJsonObjectError(Exception):
+    """Raised when an invalid JSON object/array is passed to `process_json_object`."""
+
+    def __init__(self, obj: Any) -> None:
+        """Initialize the exception."""
+        super().__init__(
+            f"Input object must be a dict or list, not {type(obj)!r}",
+        )
+
+
+def process_json_object(
+    obj: JSONObj | JSONArr,
+    /,
+    *,
+    target_type: type[V] | tuple[type[V], ...],
+    target_processor_func: TargetProcessorFunc[V],
+    pass_on_fail: bool = True,
+    log_op_func_failures: bool = False,
+    single_keys_to_remove: Sequence[str] | None = None,
+) -> None:
+    """Generic entry point to process dicts and/or lists.
+
+    Raises:
+        InvalidJsonObjectError: if an invalid JSON object/array is passed
+    """
+    if isinstance(obj, dict):
+        traverse_dict(
+            obj,
+            target_type=target_type,
+            target_processor_func=target_processor_func,
+            pass_on_fail=pass_on_fail,
+            log_op_func_failures=log_op_func_failures,
+            single_keys_to_remove=single_keys_to_remove,
+        )
+    elif isinstance(obj, list):
+        process_list(
+            obj,
+            target_type=target_type,
+            target_processor_func=target_processor_func,
+            pass_on_fail=pass_on_fail,
+            log_op_func_failures=log_op_func_failures,
+            single_keys_to_remove=single_keys_to_remove,
+        )
+    else:
+        raise InvalidJsonObjectError(obj)
