@@ -13,7 +13,10 @@ COMMAND_PATTERN = compile_regex(r"""((?:[^\s"']|"[^"]*"|'[^']*')+)""")
 
 
 def run_cmd(
-    cmd: str, exit_on_error: bool = True, shell: bool = False
+    cmd: str,
+    *,
+    exit_on_error: bool = True,
+    shell: bool = False,
 ) -> tuple[str, str]:
     """Run commands on the command line.
 
@@ -29,12 +32,16 @@ def run_cmd(
     Raises:
         RuntimeError: if the command has a non-zero exit code
     """
-
     LOGGER.debug("Running command `%s`", cmd)
 
     popen_input = cmd if shell else COMMAND_PATTERN.split(cmd)[1::2]
 
-    with Popen(popen_input, stdout=PIPE, stderr=PIPE, shell=shell) as process:
+    with Popen(  # noqa: S603
+        popen_input,
+        stdout=PIPE,
+        stderr=PIPE,
+        shell=shell,
+    ) as process:
         output, error = process.communicate()
 
         error_str = error.decode("utf-8").strip()
